@@ -54,7 +54,6 @@ import java.util.Calendar;
 import java.util.HashSet;
 import java.util.Set;
 import com.openexchange.exception.OXException;
-import com.openexchange.groupware.calendar.CalendarDataObject;
 import com.openexchange.groupware.calendar.OXCalendarExceptionCodes;
 import com.openexchange.groupware.container.CalendarObject;
 
@@ -135,8 +134,9 @@ public class RecurrenceChecker {
             throw OXCalendarExceptionCodes.INCOMPLETE_REC_INFOS_WEEKDAY.create();
         }
 
-        if (cdao.getDays() < 1 || cdao.getDays() > 127) {
-            throw OXCalendarExceptionCodes.RECURRING_MISSING_OR_WRONG_VALUE_DAYS.create(cdao.getDays());
+        final int days = cdao.getDays();
+        if (days < 1 || days > 127) {
+            throw OXCalendarExceptionCodes.RECURRING_MISSING_OR_WRONG_VALUE_DAYS.create(Integer.valueOf(days));
         }
     }
 
@@ -162,7 +162,7 @@ public class RecurrenceChecker {
         }
 
         if (cdao.getDayInMonth() < 1 || cdao.getDayInMonth() > 31) {
-            throw OXCalendarExceptionCodes.RECURRING_MISSING_MONTLY_INTERVAL.create(cdao.getDayInMonth());
+            throw OXCalendarExceptionCodes.RECURRING_MISSING_MONTLY_INTERVAL.create(Integer.valueOf(cdao.getDayInMonth()));
         }
     }
 
@@ -172,11 +172,11 @@ public class RecurrenceChecker {
         }
 
         if (cdao.getDays() < 1 || cdao.getDays() > 127) {
-            throw OXCalendarExceptionCodes.RECURRING_MISSING_OR_WRONG_VALUE_DAYS.create(cdao.getDays());
+            throw OXCalendarExceptionCodes.RECURRING_MISSING_OR_WRONG_VALUE_DAYS.create(Integer.valueOf(cdao.getDays()));
         }
 
         if (cdao.getDayInMonth() < 1 || cdao.getDayInMonth() > 5) {
-            throw OXCalendarExceptionCodes.RECURRING_MISSING_MONTLY_DAY_2.create(cdao.getDayInMonth());
+            throw OXCalendarExceptionCodes.RECURRING_MISSING_MONTLY_DAY_2.create(Integer.valueOf(cdao.getDayInMonth()));
         }
     }
 
@@ -202,7 +202,7 @@ public class RecurrenceChecker {
         }
 
         if (cdao.getDayInMonth() < 1 || cdao.getDayInMonth() > 31) {
-            throw OXCalendarExceptionCodes.RECURRING_MISSING_YEARLY_INTERVAL.create(cdao.getDayInMonth());
+            throw OXCalendarExceptionCodes.RECURRING_MISSING_YEARLY_INTERVAL.create(Integer.valueOf(cdao.getDayInMonth()));
         }
         
         checkDayInMonthOnYearly1(cdao);
@@ -221,7 +221,7 @@ public class RecurrenceChecker {
         }
         
         if (fail) {
-            throw OXCalendarExceptionCodes.RECURRING_MISSING_YEARLY_INTERVAL.create(cdao.getDayInMonth());
+            throw OXCalendarExceptionCodes.RECURRING_MISSING_YEARLY_INTERVAL.create(Integer.valueOf(cdao.getDayInMonth()));
         }
     }
 
@@ -231,13 +231,12 @@ public class RecurrenceChecker {
         }
 
         if (cdao.getDays() < 1 || cdao.getDays() > 127) {
-            throw OXCalendarExceptionCodes.RECURRING_MISSING_OR_WRONG_VALUE_DAYS.create(cdao.getDays());
+            throw OXCalendarExceptionCodes.RECURRING_MISSING_OR_WRONG_VALUE_DAYS.create(Integer.valueOf(cdao.getDays()));
         }
 
         if (cdao.getDayInMonth() < 1 || cdao.getDayInMonth() > 5) {
-            throw OXCalendarExceptionCodes.RECURRING_MISSING_YEARLY_INTERVAL.create(cdao.getDayInMonth());
+            throw OXCalendarExceptionCodes.RECURRING_MISSING_YEARLY_INTERVAL.create(Integer.valueOf(cdao.getDayInMonth()));
         }
-
     }
 
     /**
@@ -248,28 +247,25 @@ public class RecurrenceChecker {
      * @return
      */
     public static boolean containsRecurrenceInformation(final CalendarObject cdao, final int... exceptions) {
-        final Set<Integer> recurrenceFields = new HashSet<Integer>() {
-
-            {
-                add(CalendarObject.INTERVAL);
-                add(CalendarObject.DAYS);
-                add(CalendarObject.DAY_IN_MONTH);
-                add(CalendarObject.MONTH);
-                add(CalendarObject.RECURRENCE_COUNT);
-                add(CalendarObject.UNTIL);
-            }
-        };
+        final Set<Integer> recurrenceFields = new HashSet<Integer>(6);
+        recurrenceFields.add(Integer.valueOf(CalendarObject.INTERVAL));
+        recurrenceFields.add(Integer.valueOf(CalendarObject.DAYS));
+        recurrenceFields.add(Integer.valueOf(CalendarObject.DAY_IN_MONTH));
+        recurrenceFields.add(Integer.valueOf(CalendarObject.MONTH));
+        recurrenceFields.add(Integer.valueOf(CalendarObject.RECURRENCE_COUNT));
+        recurrenceFields.add(Integer.valueOf(CalendarObject.UNTIL));
 
         boolean skipType = false;
 
+        final int recurrenceType = CalendarObject.RECURRENCE_TYPE;
         for (final int exception : exceptions) {
-            recurrenceFields.remove(exception);
-            if (exception == CalendarObject.RECURRENCE_TYPE) {
+            recurrenceFields.remove(Integer.valueOf(exception));
+            if (exception == recurrenceType) {
                 skipType = true;
             }
         }
 
-        if (!skipType && cdao.contains(CalendarObject.RECURRENCE_TYPE) && (Integer)cdao.get(CalendarObject.RECURRENCE_TYPE) != CalendarObject.NO_RECURRENCE) {
+        if (!skipType && cdao.contains(recurrenceType) && ((Integer) cdao.get(recurrenceType)).intValue() != CalendarObject.NO_RECURRENCE) {
             return true;
         }
 
