@@ -50,7 +50,6 @@
 package com.openexchange.contact.storage.rdb.fields;
 
 import java.util.EnumSet;
-
 import com.openexchange.groupware.contact.helpers.ContactField;
 
 /**
@@ -63,9 +62,10 @@ public final class Fields {
     /**
      * A set of all contact fields as used by the contacts database table.
      */
+    //TODO: might be better to list the fields explicitly
     public static final EnumSet<ContactField> CONTACT_DATABASE = EnumSet.complementOf(EnumSet.of(ContactField.IMAGE1_URL,
         ContactField.IMAGE1_CONTENT_TYPE, ContactField.IMAGE_LAST_MODIFIED, ContactField.IMAGE1, ContactField.DISTRIBUTIONLIST,
-        ContactField.LAST_MODIFIED_OF_NEWEST_ATTACHMENT, ContactField.LAST_MODIFIED_UTC, ContactField.LINKS));
+        ContactField.LAST_MODIFIED_OF_NEWEST_ATTACHMENT, ContactField.LAST_MODIFIED_UTC, ContactField.LINKS, ContactField.SORT_NAME));
 
     /**
      * An array of all contact fields as used by the contacts database table.
