@@ -316,7 +316,7 @@ public class Memorizer implements Runnable {
         boolean enabledRight = false;
         try {
             enabled = ServerUserSetting.getInstance().isContactCollectionEnabled(session.getContextId(), session.getUserId());
-            enabledRight = ServerSessionAdapter.valueOf(session).getUserConfiguration().isCollectEmailAddresses();
+            enabledRight = ServerSessionAdapter.valueOf(session).getUserPermissionBits().isCollectEmailAddresses();
         } catch (final OXException e) {
             LOG.error(e.getMessage(), e);
         }
