@@ -99,14 +99,6 @@ public class ContactCollectorActivator extends HousekeepingActivator {
 
     @Override
     public void startBundle() throws Exception {
-        {
-            final ConfigurationService cService = getService(ConfigurationService.class);
-            if (!cService.getBoolProperty("com.openexchange.contactcollector.enabled", true)) {
-                final Log log = com.openexchange.log.Log.loggerFor(ContactCollectorActivator.class);
-                log.info("Canceled start-up of bundle: com.openexchange.contactcollector. Disabled by configuration setting \"com.openexchange.contactcollector.enabled=false\"");
-                return;
-            }
-        }
         /*
          * Initialize service registry with available services
          */
@@ -134,6 +126,18 @@ public class ContactCollectorActivator extends HousekeepingActivator {
             }
         };
         CCServiceRegistry.SERVICE_REGISTRY.set(serviceRegistry);
+        /*
+         * Check if disabled by configuration
+         */
+        {
+            final ConfigurationService cService = getService(ConfigurationService.class);
+            if (!cService.getBoolProperty("com.openexchange.contactcollector.enabled", true)) {
+                final Log log = com.openexchange.log.Log.loggerFor(ContactCollectorActivator.class);
+                log.info("Canceled start-up of bundle: com.openexchange.contactcollector. Disabled by configuration setting \"com.openexchange.contactcollector.enabled=false\"");
+                registerPreferenceItems();
+                return;
+            }
+        }
         /*
          * Initialize service
          */
@@ -145,6 +149,11 @@ public class ContactCollectorActivator extends HousekeepingActivator {
          */
         registerService(LoginHandlerService.class, new ContactCollectorFolderCreator());
         registerService(ContactCollectorService.class, collectorInstance);
+        registerPreferenceItems();
+    }
+
+    /** Registers PreferencesItemService instances */
+    private void registerPreferenceItems() {
         registerService(PreferencesItemService.class, new ContactCollectFolder());
         registerService(PreferencesItemService.class, new ContactCollectEnabled());
         registerService(PreferencesItemService.class, new ContactCollectOnMailAccess());
