@@ -49,6 +49,8 @@
 
 package com.openexchange.data.conversion.ical.ical4j.internal;
 
+import java.sql.Connection;
+import java.util.Date;
 import java.util.TimeZone;
 import net.fortuna.ical4j.model.DateTime;
 import net.fortuna.ical4j.model.TimeZoneRegistry;
@@ -56,8 +58,8 @@ import net.fortuna.ical4j.model.TimeZoneRegistryFactory;
 import net.fortuna.ical4j.util.TimeZones;
 import net.fortuna.ical4j.zoneinfo.outlook.OutlookTimeZoneRegistryFactory;
 import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
 import com.openexchange.data.conversion.ical.ZoneInfo;
+import com.openexchange.databaseold.Database;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.calendar.CalendarCollectionService;
 import com.openexchange.groupware.calendar.CalendarDataObject;
@@ -65,6 +67,14 @@ import com.openexchange.groupware.calendar.Constants;
 import com.openexchange.groupware.calendar.RecurringResultsInterface;
 import com.openexchange.groupware.container.Appointment;
 import com.openexchange.groupware.container.CalendarObject;
+import com.openexchange.groupware.contexts.Context;
+import com.openexchange.groupware.ldap.UserStorage;
+import com.openexchange.groupware.notify.NotificationConfig;
+import com.openexchange.groupware.notify.NotificationConfig.NotificationProperty;
+import com.openexchange.java.Strings;
+import com.openexchange.log.LogFactory;
+import com.openexchange.mail.usersetting.UserSettingMail;
+import com.openexchange.mail.usersetting.UserSettingMailStorage;
 
 /**
  *
@@ -194,6 +204,25 @@ public final class EmitterTools {
         return retval;
     }
 
+    public static String getFrom(int userId, Context ctx) throws OXException {
+        UserSettingMail userSettingMail;
+        Connection con = Database.get(ctx, true);
+        try {
+            userSettingMail = UserSettingMailStorage.getInstance().getUserSettingMail(userId, ctx, con);
+        } finally {
+            Database.back(ctx, true, con);
+        }
+
+        if (null != userSettingMail && "defaultSenderAddress".equalsIgnoreCase(NotificationConfig.getProperty(NotificationProperty.FROM_SOURCE, "primaryMail"))) {
+            String defaultSendAddress = userSettingMail.getSendAddr();
+            if (!Strings.isEmpty(defaultSendAddress)) {
+                return defaultSendAddress;
+            }
+        }
+
+        return UserStorage.getInstance().getUser(userId, ctx).getMail();
+    }
+
     public static void setCalendarCollection(final CalendarCollectionService calendarCollection) {
         EmitterTools.calendarCollection = calendarCollection;
     }
