@@ -53,12 +53,15 @@ import static com.openexchange.data.conversion.ical.ical4j.internal.EmitterTools
 import static com.openexchange.data.conversion.ical.ical4j.internal.EmitterTools.toDateTime;
 import static com.openexchange.data.conversion.ical.ical4j.internal.ParserTools.parseDateConsideringDateType;
 
+import java.util.Date;
 import java.util.List;
 import java.util.TimeZone;
 
 import net.fortuna.ical4j.model.Property;
 import net.fortuna.ical4j.model.component.CalendarComponent;
+import net.fortuna.ical4j.model.property.DateProperty;
 import net.fortuna.ical4j.model.property.DtEnd;
+import net.fortuna.ical4j.model.property.DtStart;
 
 import com.openexchange.data.conversion.ical.ConversionWarning;
 import com.openexchange.data.conversion.ical.Mode;
@@ -112,7 +115,39 @@ public final class End<T extends CalendarComponent, U extends CalendarObject> ex
      */
     @Override
     public void parse(final int index, final T component, final U calendar, final TimeZone timeZone, final Context ctx, final List<ConversionWarning> warnings) {
-        calendar.setEndDate(parseDateConsideringDateType(component, new DtEnd(), timeZone));
+        if (!overrideFullTimeSetting(component, calendar)) {
+            calendar.setEndDate(parseDateConsideringDateType(component, new DtEnd(), timeZone));
+        }
+    }
+    
+
+
+    /**
+     * Overrides fulltime setting depending on Exchange Property: X-MICROSOFT-CDO-ALLDAYEVENT
+     * 
+     * @param component
+     * @param calendar
+     */
+    private boolean overrideFullTimeSetting(T component, U calendar) {
+        boolean retval = false;
+        
+        DtEnd dtEnd = new DtEnd();
+        Property msAllDay = component.getProperty(XMicrosoftCdoAlldayEvent.property);
+        if (msAllDay != null && msAllDay.getValue().equalsIgnoreCase("true")) {
+            DateProperty dateProperty = (DateProperty)component.getProperty(dtEnd.getName());
+            int timeZoneOffset = dateProperty.getTimeZone() != null ? dateProperty.getTimeZone().getOffset(dateProperty.getDate().getTime()) : 0;
+            Date e = new Date(dateProperty.getDate().getTime() + timeZoneOffset);
+            calendar.setEndDate(e);
+            
+            if (calendar instanceof Appointment) {
+                Appointment appointment = (Appointment) calendar;
+                appointment.setFullTime(true);
+            }
+            
+            retval = true;
+        }
+        
+        return retval;
     }
 
 }
