@@ -57,6 +57,7 @@ import com.openexchange.folderstorage.FolderService;
 import com.openexchange.groupware.infostore.InfostoreFacade;
 import com.openexchange.groupware.infostore.InfostoreSearchEngine;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.quota.QuotaService;
 
 
 /**
@@ -68,7 +69,8 @@ public class InfostoreFileStorageActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[]{ InfostoreFacade.class, InfostoreSearchEngine.class, FolderService.class, ContentTypeDiscoveryService.class };
+        return new Class<?>[] { InfostoreFacade.class, InfostoreSearchEngine.class, FolderService.class,
+            ContentTypeDiscoveryService.class, QuotaService.class };
     }
 
     @Override
