@@ -169,7 +169,7 @@ public abstract class AbstractFile implements File {
                 s.append(".*");
             } else if (c == '?') {
                 s.append('.');
-            } else if (c == '(' || c == ')' || c == '[' || c == ']' || c == '$' || c == '^' || c == '.' || c == '{' || c == '}' || c == '|' || c == '\\') {
+            } else if (c == '(' || c == ')' || c == '[' || c == ']' || c == '$' || c == '^' || c == '.' || c == '{' || c == '}' || c == '|' || c == '\\'|| c == '+') {
                 s.append('\\');
                 s.append(c);
             } else {
