@@ -272,5 +272,10 @@ public class FileFieldHandling {
         public Object versionComment(final Object... args) {
             return handler.handle(Field.VERSION_COMMENT, args);
         }
+        
+        @Override
+        public Object meta(Object... args) {
+            return handler.handle(Field.META, args);
+        }
     }
 }
