@@ -50,7 +50,6 @@
 package com.openexchange.folder.json.actions;
 
 import java.util.Date;
-import java.util.Map;
 import org.json.JSONArray;
 import org.json.JSONException;
 import com.openexchange.ajax.AJAXServlet;
@@ -144,7 +143,7 @@ public final class UpdatesAction extends AbstractFolderAction {
                 includeMail ? new ContentType[] { ServiceRegistry.getInstance().getService(ContentTypeDiscoveryService.class).getByString(
                     "mail") } : null,
                 session,
-                new FolderServiceDecorator().setTimeZone(Tools.getTimeZone(timeZoneId)).setAllowedContentTypes(allowedContentTypes).put("altNames", request.getParameter("altNames")).put(PARAM_IGNORE_TRANSLATION, request.getParameter(PARAM_IGNORE_TRANSLATION)));
+                new FolderServiceDecorator().setTimeZone(Tools.getTimeZone(timeZoneId)).setAllowedContentTypes(allowedContentTypes).put("altNames", request.getParameter("altNames")));
         /*
          * Determine last-modified time stamp
          */
@@ -167,16 +166,14 @@ public final class UpdatesAction extends AbstractFolderAction {
         /*
          * Write subfolders as JSON arrays to JSON array
          */
-        final boolean ignoreTranslation = parseBoolean(request.getParameter(PARAM_IGNORE_TRANSLATION), false);
-        final Map<String, Object> params = ignoreTranslation ? parametersFor(PARAM_IGNORE_TRANSLATION, Boolean.TRUE) : null;
-        final JSONArray resultArray = FolderWriter.writeMultiple2Array(columns, result[0], session, Constants.ADDITIONAL_FOLDER_FIELD_LIST, params);
+        final JSONArray resultArray = FolderWriter.writeMultiple2Array(columns, result[0], session, Constants.ADDITIONAL_FOLDER_FIELD_LIST, null);
         try {
             final JSONArray jsonArray2 =
                 FolderWriter.writeMultiple2Array(
                     new int[] { FolderField.ID.getColumn() },
                     result[1],
                     session,
-                    Constants.ADDITIONAL_FOLDER_FIELD_LIST, params);
+                    Constants.ADDITIONAL_FOLDER_FIELD_LIST, null);
             final int len = jsonArray2.length();
             for (int i = 0; i < len; i++) {
                 resultArray.put(jsonArray2.getJSONArray(i).get(0));
