@@ -71,10 +71,10 @@ import org.json.JSONObject;
 import com.openexchange.ajax.customizer.folder.AdditionalFolderField;
 import com.openexchange.ajax.customizer.folder.AdditionalFolderFieldList;
 import com.openexchange.ajax.customizer.folder.BulkFolderField;
+import com.openexchange.ajax.tools.JSONCoercion;
 import com.openexchange.exception.OXException;
 import com.openexchange.folder.json.FolderField;
 import com.openexchange.folder.json.FolderFieldRegistry;
-import com.openexchange.folder.json.actions.AbstractFolderAction;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
 import com.openexchange.folderstorage.FolderProperty;
@@ -95,8 +95,6 @@ public final class FolderWriter {
     static final Log LOG = com.openexchange.log.Log.loggerFor(FolderWriter.class);
     static final boolean WARN = LOG.isWarnEnabled();
 
-    static final String PARAM_IGNORE_TRANSLATION = AbstractFolderAction.PARAM_IGNORE_TRANSLATION;
-
     /**
      * The default locale: en_US.
      */
@@ -353,15 +351,8 @@ public final class FolderWriter {
 
             @Override
             public void writeField(final JSONValuePutter jsonPutter, final UserizedFolder folder) throws JSONException {
-                final String name;
-                final Boolean b = jsonPutter.getParameter(PARAM_IGNORE_TRANSLATION);
-                if (null != b && b.booleanValue()) {
-                    name = folder.getName();
-                } else {
-                    final Locale locale = folder.getLocale();
-                    name = folder.getLocalizedName(locale == null ? DEFAULT_LOCALE : locale);
-                }
-                jsonPutter.put(FolderField.FOLDER_NAME.getName(), name);
+                final Locale locale = folder.getLocale();
+                jsonPutter.put(FolderField.FOLDER_NAME.getName(), folder.getLocalizedName(locale == null ? DEFAULT_LOCALE : locale));
             }
         });
         m.put(FolderField.MODULE.getColumn(), new FolderFieldWriter() {
@@ -518,6 +509,22 @@ public final class FolderWriter {
                 jsonPutter.put(FolderField.CAPABILITIES.getName(), -1 == caps ? JSONObject.NULL : Integer.valueOf(caps));
             }
         });
+        m.put(FolderField.META.getColumn(), new FolderFieldWriter() {
+            @Override
+            public void writeField(final JSONValuePutter jsonPutter, final UserizedFolder folder) throws JSONException {
+                Map<String, Object> meta =  folder.getMeta();
+                jsonPutter.put(FolderField.META.getName(), JSONCoercion.coerceToJSON(meta));
+            }
+
+        });
+        m.put(FolderField.SUPPORTED_CAPABILITIES.getColumn(), new FolderFieldWriter() {
+
+            @Override
+            public void writeField(final JSONValuePutter jsonPutter, final UserizedFolder folder) throws JSONException {
+                final Set<String> caps = folder.getSupportedCapabilities();
+                jsonPutter.put(FolderField.SUPPORTED_CAPABILITIES.getName(), null == caps ? JSONObject.NULL : new JSONArray(caps));
+            }
+        });
         STATIC_WRITERS_MAP = m;
 
         final FolderField[] all = FolderField.values();
