@@ -62,7 +62,6 @@ public final class ForceLog<V> {
      * Initializes a new {@link ForceLog} for specified value.
      *
      * @param value The value which is forced being logged
-     * @throws NullPointerException If passed value is <code>null</code>
      */
     public static <V> ForceLog<V> valueOf(final V value) {
         return new ForceLog<V>(value);
@@ -74,13 +73,9 @@ public final class ForceLog<V> {
      * Initializes a new {@link ForceLog} for specified value.
      *
      * @param value The value which is forced being logged
-     * @throws NullPointerException If passed value is <code>null</code>
      */
     private ForceLog(final V value) {
         super();
-        if (null == value) {
-            throw new NullPointerException("Value is null.");
-        }
         this.value = value;
     }
 
@@ -95,7 +90,7 @@ public final class ForceLog<V> {
 
     @Override
     public String toString() {
-        return value.toString();
+        return null == value ? "null" : value.toString();
     }
 
 }
