@@ -102,12 +102,18 @@ public final class SessiondEventConstants {
      */
     public static final String TOPIC_STORED_SESSION = "com/openexchange/sessiond/stored/session";
 
+    /**
+     * The topic on a session being 'touched', i.e. being put into the first session container.
+     */
+    public static final String TOPIC_TOUCH_SESSION = "com/openexchange/sessiond/touch/session";
+
     /**
      * An array of {@link String string} including all known topics.
      * <p>
      * Needed on event handler registration to a bundle context.
      */
-    private static final String[] TOPICS = { TOPIC_LAST_SESSION, TOPIC_REMOVE_SESSION, TOPIC_REMOVE_CONTAINER, TOPIC_REMOVE_DATA, TOPIC_ADD_SESSION, TOPIC_REACTIVATE_SESSION, TOPIC_STORED_SESSION };
+    private static final String[] TOPICS = { TOPIC_LAST_SESSION, TOPIC_REMOVE_SESSION, TOPIC_REMOVE_CONTAINER, TOPIC_REMOVE_DATA, 
+        TOPIC_ADD_SESSION, TOPIC_REACTIVATE_SESSION, TOPIC_STORED_SESSION, TOPIC_TOUCH_SESSION };
 
     /**
      * Gets an array of {@link String string} including all known topics.
