@@ -55,6 +55,7 @@ import org.apache.commons.logging.Log;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.json.JSONTokener;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceReference;
 import org.osgi.util.tracker.ServiceTracker;
@@ -161,7 +162,6 @@ public class Activator extends HousekeepingActivator {
 
                     @Override
                     public void getValue(final Session session, final Context ctx, final User user, final UserConfiguration userConfig, final Setting setting) throws OXException {
-                        try {
                             Object value = viewFactory.getView(user.getId(), ctx.getContextId()).get(propertyName, String.class);
                             if (UNDEFINED_STRING.equals(value)) {
                                 //setting.setSingleValue(UNDEFINED);
@@ -176,9 +176,6 @@ public class Activator extends HousekeepingActivator {
                             }
 
                             setting.setSingleValue(value);
-                        } catch (final OXException e) {
-                            throw new OXException(e);
-                        }
                     }
 
                     @Override
@@ -214,19 +211,14 @@ public class Activator extends HousekeepingActivator {
                                 value = "[]";
                             }
                         }
-                        try {
-                            final String oldValue = viewFactory.getView(user.getId(), ctx.getContextId()).get(propertyName, String.class);
-                            if (value != null) {
-                                // Clients have a habit of dumping the config back at us, so we only save differing values.
-                                if (!value.equals(oldValue)) {
-                                    viewFactory.getView(user.getId(), ctx.getContextId()).set("user", propertyName, value);
-                                }
-
+                        final String oldValue = viewFactory.getView(user.getId(), ctx.getContextId()).get(propertyName, String.class);
+                        if (value != null) {
+                            // Clients have a habit of dumping the config back at us, so we only save differing values.
+                            if (!value.equals(oldValue)) {
+                                viewFactory.getView(user.getId(), ctx.getContextId()).set("user", propertyName, value);
                             }
-                        } catch (final OXException e) {
-                            throw new OXException(e);
-                        }
 
+                        }
                     }
 
                 };
@@ -244,6 +236,7 @@ public class Activator extends HousekeepingActivator {
             metadataPath[metadataPath.length-1] = metadataName;
             metadataPath[0] = METADATA_PREFIX;
 
+
             final PreferencesItemService metadataItem = new PreferencesItemService() {
 
                 @Override
@@ -262,21 +255,15 @@ public class Activator extends HousekeepingActivator {
 
                         @Override
                         public void getValue(final Session session, final Context ctx, final User user, final UserConfiguration userConfig, final Setting setting) throws OXException {
-                            try {
                                 final ComposedConfigProperty<String> prop = viewFactory.getView(user.getId(), ctx.getContextId()).property(propertyName, String.class);
                                 Object value = prop.get(metadataName);
                                 try {
                                     // Let's turn this into a nice object, if it conforms to JSON
-                                    value = new JSONObject("{value: "+value+"}").get("value");
-
+                                    value = new JSONTokener(value.toString()).nextValue();
                                 } catch (final JSONException x) {
                                     // Ah well, let's pretend it's a string.
                                 }
-
                                 setting.setSingleValue(value);
-                            } catch (final OXException e) {
-                                throw new OXException(e);
-                            }
                         }
 
                         @Override
