@@ -235,7 +235,7 @@ public final class HtmlServiceImpl implements HtmlService {
                     sb.append("src=\"").append(uri.toString()).append('"');
                 }
             } catch (final MalformedURLException e) {
-                LOG.warn("Invalid URL found in \"img\" tag: " + imgTag, e);
+                LOG.debug("Invalid URL found in \"img\" tag: " + imgTag + ". Keeping original content.", e);
                 sb.append(srcMatcher.group());
             } catch (final OXException e) {
                 LOG.warn("Proxy registration failed for \"img\" tag: " + imgTag, e);
@@ -882,7 +882,7 @@ public final class HtmlServiceImpl implements HtmlService {
         return htmlFormat(plainText, true);
     }
 
-    private static final String REGEX_URL_SOLE = "\\b(?:https?://|ftp://|mailto:|news\\.|www\\.)[-\\p{L}\\p{Sc}0-9+&@#/%?=~_()|!:,.;]*[-\\p{L}\\p{Sc}0-9+&@#/%=~_()|]";
+    private static final String REGEX_URL_SOLE = "\\b(?:https?://|ftp://|mailto:|news\\.|www\\.)[-\\p{L}\\p{Sc}0-9+&@#/%?=~_()|!:,.;\\[\\]]*[-\\p{L}\\p{Sc}0-9+&@#/%=~_()|]";
 
     /**
      * The regular expression to match URLs inside text:<br>
@@ -1259,9 +1259,9 @@ public final class HtmlServiceImpl implements HtmlService {
                     final byte[] responseBody = get.getResponseBody();
                     try {
                         final String charSet = get.getResponseCharSet();
-                        css.append(new String(responseBody, null == charSet ? "ISO-8859-1" : charSet));
+                        css.append(new String(responseBody, null == charSet ? Charsets.ISO_8859_1 : Charsets.forName(charSet)));
                     } catch (final UnsupportedCharsetException e) {
-                        css.append(new String(responseBody, "ISO-8859-1"));
+                        css.append(new String(responseBody, Charsets.ISO_8859_1));
                     }
                 }
             } catch (final HttpException e) {
@@ -1290,7 +1290,7 @@ public final class HtmlServiceImpl implements HtmlService {
             sb.append("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">").append(lineSeparator);
             sb.append("<html xmlns=\"http://www.w3.org/1999/xhtml\">").append(lineSeparator);
             sb.append("<head>").append(lineSeparator);
-            sb.append("    <meta content=\"text/html; charset=").append(charset).append("\" http-equiv=\"Content-Type\"/>").append(lineSeparator);
+            sb.append("    <meta http-equiv=\"Content-Type\" content=\"text/html; charset=").append(charset).append("\" />").append(lineSeparator);
             sb.append("</head>").append(lineSeparator);
             sb.append("<body>").append(lineSeparator);
             sb.append(htmlContent);
@@ -1308,7 +1308,7 @@ public final class HtmlServiceImpl implements HtmlService {
         // Check for <head> tag
         if (!HEAD_START.matcher(htmlContent).find()) {
             sb.append("<head>").append(lineSeparator);
-            sb.append("    <meta content=\"text/html; charset=").append(charset).append("\" http-equiv=\"Content-Type\"/>").append(lineSeparator);
+            sb.append("    <meta http-equiv=\"Content-Type\" content=\"text/html; charset=").append(charset).append("\" />").append(lineSeparator);
             sb.append("</head>").append(lineSeparator);
         }
         // Check for <body> tag
@@ -1366,12 +1366,12 @@ public final class HtmlServiceImpl implements HtmlService {
                 /*-
                  * In reverse order:
                  *
-                 * "\r\n    <meta content=\"text/html; charset=" + <charset> + "\" http-equiv=\"Content-Type\" />\r\n "
+                 * "\r\n    <meta http-equiv=\"Content-Type\" content=\"text/html; charset=" + <charset> + "\" />\r\n "
                  *
                  */
-                sb.insert(start, "\" http-equiv=\"Content-Type\" />\r\n ");
+                sb.insert(start, "\" />\r\n ");
                 sb.insert(start, cs);
-                sb.insert(start, "\r\n    <meta content=\"text/html; charset=");
+                sb.insert(start, "\r\n    <meta http-equiv=\"Content-Type\" content=\"text/html; charset=");
                 html = sb.toString();
             }
         }
@@ -1752,7 +1752,10 @@ public final class HtmlServiceImpl implements HtmlService {
 
     private static final String DOCTYPE_DECL = "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\r\n\r\n";
 
-    private static String validateWithHtmlCleaner(final String htmlContent) {
+    private static final Pattern P_HTMLE_COPY = Pattern.compile("&#169;|&copy;", Pattern.CASE_INSENSITIVE);
+    private static final Pattern P_HTMLE_REG = Pattern.compile("&#174;|&reg;", Pattern.CASE_INSENSITIVE);
+
+    protected static String validateWithHtmlCleaner(final String htmlContent) {
         try {
             /*-
              * http://stackoverflow.com/questions/238036/java-html-parsing
@@ -1782,7 +1785,10 @@ public final class HtmlServiceImpl implements HtmlService {
             if (buffer.indexOf("<!DOCTYPE") < 0) {
                 buffer.insert(0, DOCTYPE_DECL);
             }
-            return buffer.toString();
+            /*
+             * Keep Unicode representation of 'copy' and 'reg' intact
+             */
+            return P_HTMLE_REG.matcher(P_HTMLE_COPY.matcher(buffer.toString()).replaceAll("\u00a9")).replaceAll("\u00ae");
         } catch (final UnsupportedEncodingException e) {
             // Cannot occur
             LOG.error("HtmlCleaner library failed to pretty-print HTML content with an unsupported encoding: " + e.getMessage(), e);
