@@ -49,6 +49,7 @@
 
 package com.openexchange.html.internal.jericho.handler;
 
+import static com.openexchange.html.HtmlServices.isNonJavaScriptURL;
 import static com.openexchange.html.internal.HtmlServiceImpl.PATTERN_URL;
 import static com.openexchange.html.internal.HtmlServiceImpl.PATTERN_URL_SOLE;
 import static com.openexchange.html.internal.css.CSSMatcher.checkCSS;
@@ -61,7 +62,6 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
-import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 import java.util.regex.Matcher;
@@ -85,6 +85,9 @@ import com.openexchange.html.services.ServiceRegistry;
 import com.openexchange.java.AsciiReader;
 import com.openexchange.java.Streams;
 import com.openexchange.java.StringAllocator;
+import com.openexchange.java.StringBuilderStringer;
+import com.openexchange.java.Stringer;
+import com.openexchange.java.Strings;
 import com.openexchange.log.LogFactory;
 
 /**
@@ -94,6 +97,8 @@ import com.openexchange.log.LogFactory;
  */
 public final class FilterJerichoHandler implements JerichoHandler {
 
+    private final static char[] IMMUNE_HTMLATTR = { ',', '.', '-', '_', '/', ';', '=', ' ' };
+
     private static final Set<String> NUM_ATTRIBS = new HashSet<String>(0);
 
     private static volatile Map<String, Map<String, Set<String>>> staticHTMLMap;
@@ -179,11 +184,13 @@ public final class FilterJerichoHandler implements JerichoHandler {
 
     private final StringBuilder attrBuilder;
 
+    private final HtmlServiceImpl htmlService;
+
     private boolean body;
 
     private boolean isCss;
 
-    private final StringBuilder cssBuffer;
+    private final Stringer cssBuffer;
 
     /**
      * Used to track all subsequent elements of a tag that ought to be removed completely.
@@ -212,10 +219,11 @@ public final class FilterJerichoHandler implements JerichoHandler {
     /**
      * Initializes a new {@link FilterJerichoHandler}.
      */
-    public FilterJerichoHandler(final int capacity) {
+    public FilterJerichoHandler(final int capacity, final HtmlServiceImpl htmlService) {
         super();
+        this.htmlService = htmlService;
         urlBuilder = new StringBuilder(256);
-        cssBuffer = new StringBuilder(256);
+        cssBuffer = new StringBuilderStringer(new StringBuilder(256));
         htmlBuilder = new StringBuilder(capacity);
         attrBuilder = new StringBuilder(128);
         if (null == staticHTMLMap) {
@@ -228,10 +236,11 @@ public final class FilterJerichoHandler implements JerichoHandler {
     /**
      * Initializes a new {@link FilterJerichoHandler}.
      */
-    public FilterJerichoHandler(final int capacity, final String mapStr) {
+    public FilterJerichoHandler(final int capacity, final String mapStr, final HtmlServiceImpl htmlService) {
         super();
+        this.htmlService = htmlService;
         urlBuilder = new StringBuilder(256);
-        cssBuffer = new StringBuilder(256);
+        cssBuffer = new StringBuilderStringer(new StringBuilder(256));
         htmlBuilder = new StringBuilder(capacity);
         attrBuilder = new StringBuilder(128);
         final Map<String, Map<String, Set<String>>> map = parseHTMLMap(mapStr);
@@ -494,10 +503,6 @@ public final class FilterJerichoHandler implements JerichoHandler {
         return (HTMLElementName.SCRIPT == check || check.startsWith("w:") || check.startsWith("o:"));
     }
 
-    private static final String CID = "cid:";
-
-    private static final Pattern PATTERN_FILENAME = Pattern.compile("([0-9a-z&&[^.\\s>\"]]+\\.[0-9a-z&&[^.\\s>\"]]+)");
-
     /**
      * Adds tag occurring in white list to HTML result.
      *
@@ -509,14 +514,22 @@ public final class FilterJerichoHandler implements JerichoHandler {
         attrBuilder.setLength(0);
         final String tagName = startTag.getName();
         final Attributes attributes = startTag.getAttributes();
-        if (simple && HTMLElementName.META.equals(tagName) && (null != attributes.get("http-equiv")) && allowedAttributes.containsKey("http-equiv")) {
+        if (simple && HTMLElementName.META.equals(tagName) && null != attributes.get("http-equiv") && allowedAttributes.containsKey("http-equiv")) {
             /*
              * Special handling for allowed meta tag which provides an allowed HTTP header indicated through 'http-equiv' attribute
              */
             for (final Attribute attribute : attributes) {
-                attrBuilder.append(' ').append(attribute.getName()).append("=\"").append(attribute.getValue()).append('"');
+                final String val = attribute.getValue();
+                if (isNonJavaScriptURL(val, "url=")) {
+                    attrBuilder.append(' ').append(attribute.getName()).append("=\"").append(htmlService.encodeForHTMLAttribute(IMMUNE_HTMLATTR, val)).append('"');
+                } else {
+                    attrBuilder.setLength(0);
+                    break;
+                }
+            }
+            if (attrBuilder.length() > 0) {
+                htmlBuilder.append('<').append(tagName).append(attrBuilder.toString()).append('>');
             }
-            htmlBuilder.append('<').append(tagName).append(attrBuilder.toString()).append('>');
             return;
         }
         /*
@@ -555,7 +568,7 @@ public final class FilterJerichoHandler implements JerichoHandler {
                             attrBuilder.append(' ').append(attr).append("=\"\"");
                             imageURLFound = true;
                         } else if (dropExternalImages && (HTMLElementName.IMG == tagName || HTMLElementName.INPUT == tagName) && "src".equals(attr)) {
-                            if (val.regionMatches(true, 0, CID, 0, 4) || PATTERN_FILENAME.matcher(val).matches()) {
+                            if (isInlineImage(val)) {
                                 // Allow inline images
                                 attrBuilder.append(' ').append(attr).append("=\"").append(CharacterReference.encode(val)).append('"');
                             } else {
@@ -582,7 +595,7 @@ public final class FilterJerichoHandler implements JerichoHandler {
                                         attrBuilder.append(' ').append(attr).append("=\"\"");
                                         imageURLFound = true;
                                     } else if (dropExternalImages && (HTMLElementName.IMG == tagName || HTMLElementName.INPUT == tagName) && "src".equals(attr)) {
-                                        if (val.regionMatches(true, 0, CID, 0, 4) || PATTERN_FILENAME.matcher(val).matches()) {
+                                        if (isInlineImage(val)) {
                                             // Allow inline images
                                             attrBuilder.append(' ').append(attr).append("=\"").append(CharacterReference.encode(val)).append('"');
                                         } else {
@@ -617,6 +630,19 @@ public final class FilterJerichoHandler implements JerichoHandler {
         htmlBuilder.append('>');
     }
 
+    // --------------------------------- Image check --------------------------------------- //
+
+    private static final String CID = "cid:";
+    private static final String DATA_BASE64 = "data:;base64,";
+    private static final Pattern PATTERN_FILENAME = Pattern.compile("([0-9a-z&&[^.\\s>\"]]+\\.[0-9a-z&&[^.\\s>\"]]+)");
+
+    private boolean isInlineImage(final String val) {
+        final String tmp = toLowerCase(val);
+        return tmp.startsWith(CID) || tmp.startsWith(DATA_BASE64) || PATTERN_FILENAME.matcher(tmp).matches();
+    }
+
+    // ----------------------------------------------------------------------------------- //
+
     private static final Pattern SPLIT_WORDS = Pattern.compile(" +");
 
     private static String prefixBlock(final String value, final String cssPrefix) {
@@ -625,7 +651,7 @@ public final class FilterJerichoHandler implements JerichoHandler {
         }
         final int length = value.length();
         int pos = 0;
-        while (pos < length && Character.isWhitespace(value.charAt(pos))) {
+        while (pos < length && Strings.isWhitespace(value.charAt(pos))) {
             pos++;
         }
         final StringBuilder builder = new StringBuilder(length << 1);
@@ -663,7 +689,7 @@ public final class FilterJerichoHandler implements JerichoHandler {
         final int len = string.length();
         boolean isWhitespace = true;
         for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = Character.isWhitespace(string.charAt(i));
+            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
         }
         return isWhitespace;
     }
@@ -702,14 +728,6 @@ public final class FilterJerichoHandler implements JerichoHandler {
         }
     }
 
-    private static boolean isNonJavaScriptURL(final String val) {
-        if (null == val) {
-            return false;
-        }
-        final String lc = val.trim().toLowerCase(Locale.US);
-        return !lc.startsWith("javascript:") && !lc.startsWith("vbscript:");
-    }
-
     @Override
     public void handleDocDeclaration(final String docDecl) {
         htmlBuilder.append(docDecl);
