@@ -128,7 +128,7 @@ public class ServiceRegistry implements ServiceLookup {
         }
         return clazz.cast(service);
     }
-    
+
     @Override
     public <S> S getOptionalService(Class<? extends S> clazz) {
     	return getService(clazz);
@@ -168,7 +168,7 @@ public class ServiceRegistry implements ServiceLookup {
 
     @Override
     public String toString() {
-        final StringBuilder sb = new StringBuilder(256);
+        final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(256);
         sb.append("Service registry:\n");
         if (services.isEmpty()) {
             sb.append("<empty>");
