@@ -61,6 +61,7 @@ import com.openexchange.publish.impl.InfostoreDocumentLoader;
 import com.openexchange.publish.impl.InfostoreFolderLoader;
 import com.openexchange.user.UserService;
 import com.openexchange.userconf.UserConfigurationService;
+import com.openexchange.userconf.UserPermissionService;
 
 /**
  * {@link LoaderActivator}
@@ -75,9 +76,9 @@ public class LoaderActivator extends HousekeepingActivator {
 
         final InfostoreFacade infostore = getService(InfostoreFacade.class);
         final UserService users = getService(UserService.class);
-        final UserConfigurationService userConfigs = getService(UserConfigurationService.class);
-        compositeLoader.registerLoader("infostore/object", new InfostoreDocumentLoader(infostore, users, userConfigs));
-        compositeLoader.registerLoader("infostore", new InfostoreFolderLoader(infostore, users, userConfigs));
+        final UserPermissionService userPermissions = getService(UserPermissionService.class);
+        compositeLoader.registerLoader("infostore/object", new InfostoreDocumentLoader(infostore, users, userPermissions));
+        compositeLoader.registerLoader("infostore", new InfostoreFolderLoader(infostore, users, userPermissions));
 
         final ContactFolderLoader contactLoader = new ContactFolderLoader(getService(ContactService.class));
         compositeLoader.registerLoader("contacts", contactLoader);
@@ -92,7 +93,7 @@ public class LoaderActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class[] { CacheService.class, InfostoreFacade.class, UserService.class, UserConfigurationService.class, ContactService.class };
+        return new Class[] { CacheService.class, InfostoreFacade.class, UserService.class, UserPermissionService.class, ContactService.class };
     }
 
 }
