@@ -136,11 +136,6 @@ public class PublicationSession implements Session {
         return null;
     }
 
-    @Override
-    public void removeRandomToken() {
-        throw new UnsupportedOperationException();
-    }
-
     @Override
     public void setParameter(final String name, final Object value) {
         // Nothing to remember.
@@ -177,4 +172,9 @@ public class PublicationSession implements Session {
         // Nothing to do.
     }
 
+    @Override
+    public boolean isTransient() {
+        return false;
+    }
+
 }
