@@ -51,12 +51,17 @@ package com.openexchange.secret.recovery.json;
 
 import java.util.Collection;
 import java.util.Map;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
 import com.openexchange.exception.OXException;
+import com.openexchange.osgi.ServiceSet;
+import com.openexchange.secret.recovery.EncryptedItemCleanUpService;
+import com.openexchange.secret.recovery.SecretMigrator;
 import com.openexchange.secret.recovery.json.action.CheckAction;
 import com.openexchange.secret.recovery.json.action.CleanUpAction;
+import com.openexchange.secret.recovery.json.action.RemoveAction;
 import com.openexchange.secret.recovery.json.action.MigrateAction;
 import com.openexchange.server.ServiceLookup;
 
@@ -73,13 +78,16 @@ public class SecretRecoveryActionFactory implements AJAXActionServiceFactory {
      * Initializes a new {@link SecretRecoveryActionFactory}.
      *
      * @param services The service look-up
+     * @param cleanUpServices 
+     * @param secretMigrators 
      */
-    public SecretRecoveryActionFactory(final ServiceLookup services) {
+    public SecretRecoveryActionFactory(final ServiceLookup services, Set<SecretMigrator> secretMigrators, Set<EncryptedItemCleanUpService> cleanUpServices) {
         super();
         actions = new ConcurrentHashMap<String, AJAXActionService>(3);
         actions.put("check", new CheckAction(services));
-        actions.put("migrate", new MigrateAction(services));
-        actions.put("clean_up", new CleanUpAction(services));
+        actions.put("migrate", new MigrateAction(services, secretMigrators));
+        actions.put("clean_up", new CleanUpAction(services, cleanUpServices));
+        actions.put("remove", new RemoveAction(services, cleanUpServices));
     }
 
     @Override
