@@ -59,6 +59,7 @@ import java.util.Arrays;
 import java.util.Enumeration;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
@@ -106,8 +107,8 @@ import com.openexchange.sessiond.impl.IPRange;
 import com.openexchange.sessiond.impl.SubnetMask;
 import com.openexchange.sessiond.impl.ThreadLocalSessionHolder;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
-import com.openexchange.tools.servlet.CountingHttpServletRequest;
 import com.openexchange.tools.servlet.RateLimitedException;
+import com.openexchange.tools.servlet.http.Cookies;
 import com.openexchange.tools.servlet.http.Tools;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.session.ServerSessionAdapter;
@@ -221,38 +222,56 @@ public abstract class SessionServlet extends AJAXServlet {
         if (sessiondService == null) {
             throw ServiceExceptionCode.SERVICE_UNAVAILABLE.create(SessiondService.class.getName());
         }
-        ServerSession session = null;
+        final ServerSession session;
         {
             final String sSession = req.getParameter("session");
-            if (sSession != null && !sSession.equals("")) {
+            if (sSession != null && sSession.length() > 0) {
                 final String sessionId = getSessionId(req);
                 session = getSession(req, sessionId, sessiondService);
                 verifySession(req, sessiondService, sessionId, session);
                 rememberSession(req, session);
+            } else {
+                session = null;
             }
         }
         // Try public session
-        final Cookie[] cookies = req.getCookies();
+        findPublicSessionId(req, session, sessiondService);
+    }
+
+    private static final String PUBLIC_SESSION_NAME = Login.PUBLIC_SESSION_NAME;
+    private static final String PARAM_ALTERNATIVE_ID = Session.PARAM_ALTERNATIVE_ID;
+
+    /**
+     * Looks-up <code>"open-xchange-public-session"</code> cookie and remember appropriate session if possible to validate it.
+     *
+     * @param req The HTTP request
+     * @param session The looked-up session
+     * @param sessiondService The SessionD service
+     * @throws OXException If public session cannot be created
+     */
+    protected void findPublicSessionId(final HttpServletRequest req, final ServerSession session, final SessiondService sessiondService) throws OXException {
+        final Map<String, Cookie> cookies = Cookies.cookieMapFor(req);
         if (cookies != null) {
-            ServerSession simpleSession = null;
-        	for (final Cookie cookie : cookies) {
-                if (Login.PUBLIC_SESSION_NAME.equals(cookie.getName())) {
-                    final String altId = cookie.getValue();
-                    if (null != altId && null != session && altId.equals(session.getParameter(Session.PARAM_ALTERNATIVE_ID))) {
-                        // same session
-                        simpleSession = session;
-                    } else {
-                        // lookup session by alternative id
-                        simpleSession = ServerSessionAdapter.valueOf(sessiondService.getSessionByAlternativeId(cookie.getValue()));
+            final Cookie cookie = cookies.get(PUBLIC_SESSION_NAME);
+            if (null != cookie) {
+                final String altId = cookie.getValue();
+                if (null != altId && null != session && altId.equals(session.getParameter(PARAM_ALTERNATIVE_ID))) {
+                    // same session (thus already verified)
+                    rememberPublicSession(req, session);
+                } else {
+                    // Lookup session by alternative id
+                    final ServerSession publicSession = null == altId ? null : ServerSessionAdapter.valueOf(sessiondService.getSessionByAlternativeId(altId));
+                    if (publicSession != null) {
+                        try {
+                            checkSecret(hashSource, req, publicSession, false);
+                            verifySession(req, sessiondService, publicSession.getSessionID(), publicSession);
+                            rememberPublicSession(req, publicSession);
+                        } catch (final OXException e) {
+                            // Verification of public session failed
+                        }
                     }
-                    break;
                 }
             }
-        	if (simpleSession != null) {
-        	    checkSecret(hashSource, req, simpleSession);
-        		verifySession(req, sessiondService, simpleSession.getSessionID(), simpleSession);
-        		rememberPublicSession(req, simpleSession);
-        	}
         }
     }
 
@@ -316,7 +335,7 @@ public abstract class SessionServlet extends AJAXServlet {
                     threadCounter.increment(sessionId);
                 }
             }
-            super.service(new CountingHttpServletRequest(req), resp);
+            super.service(req, resp);
         } catch (final RateLimitedException e) {
             resp.setContentType("text/plain; charset=UTF-8");
             resp.sendError(429, "Too Many Requests - Your request is being rate limited.");
@@ -476,18 +495,11 @@ public abstract class SessionServlet extends AJAXServlet {
                     sb.append(" and is not covered by IP white-list or netmask.");
                     LOG.info(sb.toString());
                 }
-                throw SessionExceptionCodes.WRONG_CLIENT_IP.create();
+                throw SessionExceptionCodes.WRONG_CLIENT_IP.create(session.getLocalIp(), null == actual ? "<unknown>" : actual);
             }
-            if (null != actual) {
-                if (isWhitelistedClient(session, whitelist)) {
-                    // change IP in session so the IMAP NOOP command contains the correct client IP address (Bug #21842)
-                    session.setLocalIp(actual);
-                } else if (!doCheck) {
-                    // Do not change session's IP address anymore in case of USM/EAS (Bug #29136)
-                    if (!isUsmEas(session.getClient())) {
-                        session.setLocalIp(actual);
-                    }
-                }
+            if (null != actual && (!doCheck || isWhitelistedClient(session, whitelist))) {
+                // change IP in session so the IMAP NOOP command contains the correct client IP address (Bug #21842)
+                session.setLocalIp(actual);
             }
             if (DEBUG && !isWhitelistedFromIPCheck(actual, ranges) && !isWhitelistedClient(session, whitelist)) {
                 final StringBuilder sb = new StringBuilder(64);
@@ -502,14 +514,6 @@ public abstract class SessionServlet extends AJAXServlet {
         }
     }
 
-    private static boolean isUsmEas(final String clientId) {
-        if (Strings.isEmpty(clientId)) {
-            return false;
-        }
-        final String uc = Strings.toUpperCase(clientId);
-        return uc.startsWith("USM-EAS") || uc.startsWith("USM-JSON");
-    }
-
     /**
      * White listed clients are necessary for the Mobile Web Interface. This clients often change their IP address in mobile data networks.
      */
@@ -597,7 +601,7 @@ public abstract class SessionServlet extends AJAXServlet {
     public static ServerSession getSession(final CookieHashSource source, final HttpServletRequest req, final String sessionId, final SessiondService sessiondService, final SessionSecretChecker optChecker) throws OXException {
         final Session session = sessiondService.getSession(sessionId);
         if (null == session) {
-            if (INFO) {
+            if (INFO && !"unset".equals(sessionId)) {
                 LOG.info("There is no session associated with session identifier: " + sessionId);
             }
             throw SessionExceptionCodes.SESSION_EXPIRED.create(sessionId);
@@ -653,12 +657,26 @@ public abstract class SessionServlet extends AJAXServlet {
      * @param source    The configured CookieHashSource
      * @param req       The incoming HttpServletRequest
      * @param session   The Session object looked up for the incoming request
+     * @param logInfo   Whether to log info or not
      * @throws OXException If the secrets differ
      */
     public static void checkSecret(final CookieHashSource source, final HttpServletRequest req, final Session session) throws OXException {
+        checkSecret(source, req, session, INFO);
+    }
+
+    /**
+     * Check if the secret encoded in the open-xchange-secret Cookie matches the secret saved in the Session.
+     *
+     * @param source    The configured CookieHashSource
+     * @param req       The incoming HttpServletRequest
+     * @param session   The Session object looked up for the incoming request
+     * @param logInfo   Whether to log info or not
+     * @throws OXException If the secrets differ
+     */
+    public static void checkSecret(final CookieHashSource source, final HttpServletRequest req, final Session session, final boolean logInfo) throws OXException {
         final String secret = extractSecret(source, req, session.getHash(), session.getClient(), (String) session.getParameter("user-agent"));
         if (secret == null || !session.getSecret().equals(secret)) {
-            if (INFO && null != secret) {
+            if (logInfo && null != secret) {
                 LOG.info("Session secret is different. Given secret \"" + secret + "\" differs from secret in session \"" + session.getSecret() + "\".");
             }
             final OXException oxe = SessionExceptionCodes.WRONG_SESSION_SECRET.create();
@@ -679,6 +697,8 @@ public abstract class SessionServlet extends AJAXServlet {
         return extractSecret(cookieHash, req, hash, client, null);
     }
 
+    private static final String SECRET_PREFIX = Login.SECRET_PREFIX;
+
     /**
      * Extracts the secret string from specified cookies using given hash string.
      *
@@ -689,28 +709,20 @@ public abstract class SessionServlet extends AJAXServlet {
      * @return The secret string or <code>null</code>
      */
     public static String extractSecret(final CookieHashSource cookieHash, final HttpServletRequest req, final String hash, final String client, final String originalUserAgent) {
-        final Cookie[] cookies = req.getCookies();
+        final Map<String, Cookie> cookies = Cookies.cookieMapFor(req);
         if (null != cookies) {
-            String cookieName = Login.SECRET_PREFIX + getHash(cookieHash, req, hash, client);
-            for (final Cookie cookie : cookies) {
-                if (cookieName.equals(cookie.getName())) {
+            Cookie cookie = cookies.get(SECRET_PREFIX + getHash(cookieHash, req, hash, client));
+            if (null != cookie) {
+                return cookie.getValue();
+            }
+            if (isSafariMediaPlayer(req.getHeader("User-Agent"), originalUserAgent)) {
+                cookie = cookies.get(SECRET_PREFIX + hash);
+                if (null != cookie) {
                     return cookie.getValue();
                 }
             }
-            final String userAgent = req.getHeader("User-Agent");
-            if (null != userAgent && null != originalUserAgent) {
-                final BrowserDetector browserDetector = new BrowserDetector(originalUserAgent);
-                if (browserDetector.isSafari() && toLowerCase(userAgent).startsWith("applecoremedia/")) {
-                    cookieName = Login.SECRET_PREFIX + hash;
-                    for (final Cookie cookie : cookies) {
-                        if (cookieName.equals(cookie.getName())) {
-                            return cookie.getValue();
-                        }
-                    }
-                }
-            }
             if (INFO) {
-                LOG.info("Didn't find an appropriate Cookie for name \"" + cookieName + "\" (CookieHashSource=" + cookieHash.toString() + ") which provides the session secret.");
+                LOG.info("Didn't find an appropriate Cookie for name \"" + (SECRET_PREFIX + getHash(cookieHash, req, hash, client)) + "\" (CookieHashSource=" + cookieHash.toString() + ") which provides the session secret.");
             }
         } else if (INFO) {
             LOG.info("Missing Cookies in HTTP request. No session secret can be looked up.");
@@ -718,6 +730,10 @@ public abstract class SessionServlet extends AJAXServlet {
         return null;
     }
 
+    private static boolean isSafariMediaPlayer(final String currentUserAgent, final String sessionUserAgent) {
+        return null != currentUserAgent && null != sessionUserAgent && toLowerCase(currentUserAgent).startsWith("applecoremedia/") && new BrowserDetector(sessionUserAgent).isSafari();
+    }
+
     /**
      * Gets the appropriate hash for specified request.
      *
@@ -765,31 +781,28 @@ public abstract class SessionServlet extends AJAXServlet {
      * @param resp The HTTP response
      */
     public static void removeOXCookies(final String hash, final HttpServletRequest req, final HttpServletResponse resp) {
-        final Cookie[] cookies = req.getCookies();
+        final Map<String, Cookie> cookies = Cookies.cookieMapFor(req);
         if (cookies == null) {
             return;
         }
-        final List<String> cookieNames = Arrays.asList(Login.SESSION_PREFIX + hash, Login.SECRET_PREFIX + hash, Login.PUBLIC_SESSION_NAME);
-        for (final Cookie cookie : cookies) {
-            final String name = cookie.getName();
-
-            for (final String string : cookieNames) {
-                if (name.startsWith(string)) {
-                    final String value = cookie.getValue();
-                    final Cookie respCookie = new Cookie(name, value);
-                    respCookie.setPath("/");
-                    final String domain = getDomainValue(req.getServerName());
-                    if (null != domain) {
-                        respCookie.setDomain(domain);
-                        // Once again without domain parameter
-                        final Cookie respCookie2 = new Cookie(name, value);
-                        respCookie2.setPath("/");
-                        respCookie2.setMaxAge(0); // delete
-                        resp.addCookie(respCookie2);
-                    }
-                    respCookie.setMaxAge(0); // delete
-                    resp.addCookie(respCookie);
+        final List<String> cookieNames = Arrays.asList(Login.SESSION_PREFIX + hash, SECRET_PREFIX + hash, Login.PUBLIC_SESSION_NAME);
+        for (final String cookieName : cookieNames) {
+            final Cookie cookie = cookies.get(cookieName);
+            if (null != cookie) {
+                final String value = cookie.getValue();
+                final Cookie respCookie = new Cookie(cookieName, value);
+                respCookie.setPath("/");
+                final String domain = getDomainValue(req.getServerName());
+                if (null != domain) {
+                    respCookie.setDomain(domain);
+                    // Once again without domain parameter
+                    final Cookie respCookie2 = new Cookie(cookieName, value);
+                    respCookie2.setPath("/");
+                    respCookie2.setMaxAge(0); // delete
+                    resp.addCookie(respCookie2);
                 }
+                respCookie.setMaxAge(0); // delete
+                resp.addCookie(respCookie);
             }
         }
     }
@@ -801,28 +814,27 @@ public abstract class SessionServlet extends AJAXServlet {
      * @param resp The HTTP Servlet response
      */
     public static void removeJSESSIONID(final HttpServletRequest req, final HttpServletResponse resp) {
-        final Cookie[] cookies = req.getCookies();
+        final Map<String, Cookie> cookies = Cookies.cookieMapFor(req);
         if (cookies == null) {
             return;
         }
-        for (final Cookie cookie : cookies) {
-            final String name = cookie.getName();
-            if (Tools.JSESSIONID_COOKIE.equals(name)) {
-                final String value = cookie.getValue();
-                final Cookie respCookie = new Cookie(name, value);
-                respCookie.setPath("/");
-                final String domain = extractDomainValue(value);
-                if (null != domain) {
-                    respCookie.setDomain(domain);
-                    // Once again without domain parameter
-                    final Cookie respCookie2 = new Cookie(name, value);
-                    respCookie2.setPath("/");
-                    respCookie2.setMaxAge(0); // delete
-                    resp.addCookie(respCookie2);
-                }
-                respCookie.setMaxAge(0); // delete
-                resp.addCookie(respCookie);
+        final String name = Tools.JSESSIONID_COOKIE;
+        final Cookie cookie = cookies.get(name);
+        if (null != cookie) {
+            final String value = cookie.getValue();
+            final Cookie respCookie = new Cookie(name, value);
+            respCookie.setPath("/");
+            final String domain = extractDomainValue(value);
+            if (null != domain) {
+                respCookie.setDomain(domain);
+                // Once again without domain parameter
+                final Cookie respCookie2 = new Cookie(name, value);
+                respCookie2.setPath("/");
+                respCookie2.setMaxAge(0); // delete
+                resp.addCookie(respCookie2);
             }
+            respCookie.setMaxAge(0); // delete
+            resp.addCookie(respCookie);
         }
     }
 
