@@ -50,6 +50,7 @@
 package com.openexchange.ajax.parser;
 
 import org.json.JSONException;
+import org.json.JSONObject;
 
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.attach.AttachmentField;
@@ -74,6 +75,10 @@ public class AttachmentParser {
         }
     }
 
+    public AttachmentMetadata getAttachmentMetadata(final JSONObject json) {
+        return new JSONAttachmentMetadata(json);
+    }
+
     public AttachmentMetadata getAttachmentMetadata(final String json) throws JSONException {
         return new JSONAttachmentMetadata(json);
     }
