@@ -145,10 +145,10 @@ public final class CustomCharsetProvider extends CharsetProvider {
         try {
             charset = Charset.forName(delegateName);
         } catch (final IllegalCharsetNameException e) {
-            LOG.error(new StringBuilder("Illegal charset name \"").append(e.getCharsetName()).append('"').toString(), e);
+            LOG.error(new com.openexchange.java.StringAllocator("Illegal charset name \"").append(e.getCharsetName()).append('"').toString(), e);
             return false;
         } catch (final UnsupportedCharsetException e) {
-            LOG.error(new StringBuilder("Detected no support for charset \"").append(e.getCharsetName()).append('"').toString(), e);
+            LOG.error(new com.openexchange.java.StringAllocator("Detected no support for charset \"").append(e.getCharsetName()).append('"').toString(), e);
             return false;
         }
         return addAliasCharset(charset, canonicalName, aliases);
@@ -211,10 +211,10 @@ public final class CustomCharsetProvider extends CharsetProvider {
         try {
             charset = Charset.forName(delegateName);
         } catch (final IllegalCharsetNameException e) {
-            LOG.error(new StringBuilder("Illegal charset name \"").append(e.getCharsetName()).append('"').toString(), e);
+            LOG.error(new com.openexchange.java.StringAllocator("Illegal charset name \"").append(e.getCharsetName()).append('"').toString(), e);
             return false;
         } catch (final UnsupportedCharsetException e) {
-            LOG.error(new StringBuilder("Detected no support for charset \"").append(e.getCharsetName()).append('"').toString(), e);
+            LOG.error(new com.openexchange.java.StringAllocator("Detected no support for charset \"").append(e.getCharsetName()).append('"').toString(), e);
             return false;
         }
         return addStartsWithCharset(charset, startsWithName);
