@@ -52,6 +52,8 @@ package com.openexchange.folderstorage;
 import java.io.Serializable;
 import java.util.Date;
 import java.util.Locale;
+import java.util.Map;
+import java.util.Set;
 
 /**
  * {@link Folder} - A folder.
@@ -441,6 +443,30 @@ public interface Folder extends Serializable, Cloneable {
      */
     void setBits(final int bits);
 
+    /**
+     * Sets dynamic metadata
+     */
+    void setMeta(Map<String, Object> meta);
+
+    /**
+     * Gets dynamic metadata
+     */
+    Map<String, Object> getMeta();
+
+    /**
+     * Gets a list of supported capabilities.
+     *
+     * @return The supported capabilities
+     */
+    Set<String> getSupportedCapabilities();
+
+    /**
+     * Sets the list of supported capabilities.
+     *
+     * @param capabilitites The capabilities to set
+     */
+    void setSupportedCapabilities(Set<String> capabilities);
+
     /**
      * Creates and returns a copy of this object.
      *
