@@ -77,14 +77,14 @@ public final class UserLockManagement {
         return INSTANCE;
     }
 
-    private final ConcurrentMap<Key, ReadWriteLock> map;
+    private final ConcurrentMap<Integer, ConcurrentMap<Integer, ReadWriteLock>> map;
 
     /**
      * Initializes a new {@link UserLockManagement}.
      */
     private UserLockManagement() {
         super();
-        map = new ConcurrentHashMap<Key, ReadWriteLock>();
+        map = new ConcurrentHashMap<Integer, ConcurrentMap<Integer, ReadWriteLock>>(32);
     }
 
     /**
@@ -100,10 +100,25 @@ public final class UserLockManagement {
      * @param session The session
      */
     public void dropFor(final Session session) {
-        map.remove(keyFor(session));
+        final ConcurrentMap<Integer, ReadWriteLock> userMap = map.remove(Integer.valueOf(session.getContextId()));
+        if (null != userMap) {
+            userMap.remove(Integer.valueOf(session.getUserId()));
+            if (LOG.isDebugEnabled()) {
+                LOG.debug(new com.openexchange.java.StringAllocator("Cleaned folder locks for user ").append(session.getUserId()).append(
+                    " in context ").append(session.getContextId()).toString());
+            }
+        }
+    }
+
+    /**
+     * Drops locks for given context.
+     *
+     * @param contextId The context identifier
+     */
+    public void dropFor(final int contextId) {
+        map.remove(Integer.valueOf(contextId));
         if (LOG.isDebugEnabled()) {
-            LOG.debug(new StringBuilder("Cleaned folder locks for user ").append(session.getUserId()).append(" in context ").append(
-                session.getContextId()).toString());
+            LOG.debug(new com.openexchange.java.StringAllocator("Cleaned folder locks for context ").append(contextId).toString());
         }
     }
 
@@ -125,11 +140,18 @@ public final class UserLockManagement {
      * @return The read-write lock
      */
     public ReadWriteLock getFor(final int userId, final int contextId) {
-        final Key key = keyFor(userId, contextId);
-        ReadWriteLock readWriteLock = map.get(key);
+        ConcurrentMap<Integer, ReadWriteLock> userMap = map.remove(Integer.valueOf(contextId));
+        if (null == userMap) {
+            final ConcurrentMap<Integer, ReadWriteLock> newUserMap = new ConcurrentHashMap<Integer, ReadWriteLock>(32);
+            userMap = map.putIfAbsent(Integer.valueOf(contextId), newUserMap);
+            if (null == userMap) {
+                userMap = newUserMap;
+            }
+        }
+        ReadWriteLock readWriteLock = userMap.get(Integer.valueOf(userId));
         if (null == readWriteLock) {
             final ReadWriteLock nrwl = new ReentrantReadWriteLock();
-            readWriteLock = map.putIfAbsent(key, nrwl);
+            readWriteLock = userMap.putIfAbsent(Integer.valueOf(userId), nrwl);
             if (null == readWriteLock) {
                 readWriteLock = nrwl;
             }
@@ -144,59 +166,11 @@ public final class UserLockManagement {
      * @return The lock or <code>null</code> if absent
      */
     public ReadWriteLock optFor(final Session session) {
-        return map.get(keyFor(session));
-    }
-
-    private static Key keyFor(final Session session) {
-        return new Key(session.getUserId(), session.getContextId());
-    }
-
-    private static Key keyFor(final int userId, final int contextId) {
-        return new Key(userId, contextId);
-    }
-
-    private static final class Key {
-
-        private final int cid;
-
-        private final int user;
-
-        private final int hash;
-
-        protected Key(final int user, final int cid) {
-            super();
-            this.user = user;
-            this.cid = cid;
-            final int prime = 31;
-            int result = 1;
-            result = prime * result + cid;
-            result = prime * result + user;
-            hash = result;
+        final ConcurrentMap<Integer, ReadWriteLock> userMap = map.remove(Integer.valueOf(session.getContextId()));
+        if (null == userMap) {
+            return null;
         }
-
-        @Override
-        public int hashCode() {
-            return hash;
-        }
-
-        @Override
-        public boolean equals(final Object obj) {
-            if (this == obj) {
-                return true;
-            }
-            if (!(obj instanceof Key)) {
-                return false;
-            }
-            final Key other = (Key) obj;
-            if (cid != other.cid) {
-                return false;
-            }
-            if (user != other.user) {
-                return false;
-            }
-            return true;
-        }
-
+        return userMap.get(Integer.valueOf(session.getUserId()));
     }
 
 }
