@@ -66,7 +66,6 @@ import com.openexchange.folderstorage.cache.CacheFolderStorage;
 import com.openexchange.folderstorage.internal.StorageParametersImpl;
 import com.openexchange.folderstorage.mail.MailFolderType;
 import com.openexchange.log.LogProperties;
-import com.openexchange.log.Props;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.sessiond.SessiondService;
@@ -253,12 +252,7 @@ public final class FolderMap {
                 return;
             }
             if (LogProperties.isEnabled()) {
-                final Props properties = LogProperties.getLogProperties();
-                properties.put(LogProperties.Name.SESSION_SESSION_ID, session.getSessionID());
-                properties.put(LogProperties.Name.SESSION_USER_ID, Integer.valueOf(session.getUserId()));
-                properties.put(LogProperties.Name.SESSION_CONTEXT_ID, Integer.valueOf(session.getContextId()));
-                final String client  = session.getClient();
-                properties.put(LogProperties.Name.SESSION_CLIENT_ID, client == null ? "unknown" : client);
+                LogProperties.putSessionProperties(session);
             }
             ThreadPools.getThreadPool().submit(ThreadPools.trackableTask(new LoadSubfolders(folder, treeId, this, session)), AbortBehavior.getInstance());
         } catch (final Exception e) {
