@@ -61,6 +61,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.FileStorageAccount;
 import com.openexchange.file.storage.FileStorageAccountManager;
 import com.openexchange.file.storage.FileStorageAccountManagerLookupService;
+import com.openexchange.file.storage.FileStorageFolder;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
 import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.database.getfolder.SystemInfostoreFolder;
@@ -75,7 +76,7 @@ import com.openexchange.groupware.i18n.FolderStrings;
 import com.openexchange.groupware.infostore.InfostoreFacades;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
-import com.openexchange.groupware.userconfiguration.UserConfiguration;
+import com.openexchange.groupware.userconfiguration.UserPermissionBits;
 import com.openexchange.mail.MailSessionParameterNames;
 import com.openexchange.preferences.ServerUserSetting;
 import com.openexchange.server.ServiceExceptionCode;
@@ -251,7 +252,7 @@ public final class DatabaseFolderConverter {
      * @return The converted {@link DatabaseFolder} instance
      * @throws OXException If conversion fails
      */
-    public static DatabaseFolder convert(final FolderObject fo, final User user, final UserConfiguration userConfiguration, final Context ctx, final Session session, final boolean altNames, final Connection con) throws OXException {
+    public static DatabaseFolder convert(final FolderObject fo, final User user, final UserPermissionBits userConfiguration, final Context ctx, final Session session, final boolean altNames, final Connection con) throws OXException {
         try {
             final int folderId = fo.getObjectID();
             if (folderId < FolderObject.MIN_FOLDER_ID) { // Possibly a system folder
@@ -371,7 +372,7 @@ public final class DatabaseFolderConverter {
         }
     }
 
-    private static DatabaseFolder handleDatabaseFolder(final DatabaseFolder databaseFolder, final int folderId, final FolderObject fo, final Session session, final User user, final UserConfiguration userConfiguration, final Context ctx, final Connection con) throws OXException, SQLException {
+    private static DatabaseFolder handleDatabaseFolder(final DatabaseFolder databaseFolder, final int folderId, final FolderObject fo, final Session session, final User user, final UserPermissionBits userConfiguration, final Context ctx, final Connection con) throws OXException, SQLException {
         final int userId = user.getId();
         if (FolderObject.PRIVATE == fo.getType() && userId != databaseFolder.getCreatedBy()) { // Shared
             /*
@@ -504,6 +505,10 @@ public final class DatabaseFolderConverter {
                 }
             }
         }
+        /*
+         * assume all supported capabilities for database folders
+         */
+        databaseFolder.setSupportedCapabilities(FileStorageFolder.ALL_CAPABILITIES);
         return databaseFolder;
     }
 
