@@ -61,7 +61,7 @@ import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.i18n.FolderStrings;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.tools.iterator.FolderObjectIterator;
-import com.openexchange.groupware.userconfiguration.UserConfiguration;
+import com.openexchange.groupware.userconfiguration.UserPermissionBits;
 import com.openexchange.tools.oxfolder.OXFolderIteratorSQL;
 
 /**
@@ -91,7 +91,7 @@ public final class VirtualListFolder {
      * @return <code>true</code> if specified virtual folder identifier exists; otherwise <code>false</code>
      * @throws OXException If checking existence fails
      */
-    public static boolean existsVirtualListFolder(final int folderId, final User user, final UserConfiguration userConfiguration, final Context ctx, final Connection con) throws OXException {
+    public static boolean existsVirtualListFolder(final int folderId, final User user, final UserPermissionBits userConfiguration, final Context ctx, final Connection con) throws OXException {
         final int module;
         if (FolderObject.VIRTUAL_LIST_TASK_FOLDER_ID == folderId) {
             // Task
@@ -181,7 +181,7 @@ public final class VirtualListFolder {
      * @return The subfolder identifiers of database folder representing given virtual folder
      * @throws OXException If returning database folder fails
      */
-    public static int[] getVirtualListFolderSubfoldersAsInt(final int folderId, final User user, final UserConfiguration userConfiguration, final Context ctx, final Connection con) throws OXException {
+    public static int[] getVirtualListFolderSubfoldersAsInt(final int folderId, final User user, final UserPermissionBits userConfiguration, final Context ctx, final Connection con) throws OXException {
         /*
          * Get subfolders
          */
@@ -226,7 +226,7 @@ public final class VirtualListFolder {
      * @return The subfolder identifiers of database folder representing given virtual folder
      * @throws OXException If returning database folder fails
      */
-    public static List<String[]> getVirtualListFolderSubfolders(final int folderId, final User user, final UserConfiguration userConfiguration, final Context ctx, final Connection con) throws OXException {
+    public static List<String[]> getVirtualListFolderSubfolders(final int folderId, final User user, final UserPermissionBits userConfiguration, final Context ctx, final Connection con) throws OXException {
         /*
          * Get subfolders
          */
