@@ -73,7 +73,7 @@ import com.openexchange.folderstorage.internal.StorageParametersImpl;
 import com.openexchange.folderstorage.outlook.OutlookFolderStorage;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
-import com.openexchange.groupware.userconfiguration.UserConfiguration;
+import com.openexchange.groupware.userconfiguration.UserPermissionBits;
 import com.openexchange.tools.session.ServerSession;
 
 /**
@@ -131,9 +131,9 @@ public abstract class AbstractPerformer {
         this.folderStorageDiscoverer = folderStorageDiscoverer;
         this.session = session;
         // Pre-Initialize session
-        final UserConfiguration userConfiguration = session.getUserConfiguration();
-        if (null != userConfiguration) {
-            userConfiguration.isMultipleMailAccounts();
+        final UserPermissionBits userPermissionBits = session.getUserPermissionBits();
+        if (null != userPermissionBits) {
+            userPermissionBits.isMultipleMailAccounts();
         }
         user = session.getUser();
         context = session.getContext();
