@@ -109,7 +109,9 @@ public final class MailFolderImpl extends AbstractFolder implements FolderExtens
      * The mail folder content type.
      */
     public static enum MailFolderType {
-        NONE(MailContentType.getInstance(), 0), ROOT(SystemContentType.getInstance(), 0), INBOX(MailContentType.getInstance(), 7), // FolderObject.MAIL
+        NONE(MailContentType.getInstance(), 0),
+        ROOT(SystemContentType.getInstance(), 0),
+        INBOX(MailContentType.getInstance(), 7), // FolderObject.MAIL
         DRAFTS(DraftsContentType.getInstance(), 9),
         SENT(SentContentType.getInstance(), 10),
         SPAM(SpamContentType.getInstance(), 11),
