@@ -51,6 +51,8 @@ package com.openexchange.folderstorage.outlook;
 
 import java.util.Date;
 import java.util.Locale;
+import java.util.Map;
+import java.util.Set;
 import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.Folder;
 import com.openexchange.folderstorage.FolderExtension;
@@ -93,6 +95,7 @@ public final class OutlookFolder implements FolderExtension {
 
     private String newId;
 
+
     /**
      * Initializes a {@link OutlookFolder} with specified real folder.
      *
@@ -442,6 +445,18 @@ public final class OutlookFolder implements FolderExtension {
         // Nothing to do
     }
 
+
+
+    @Override
+    public void setMeta(Map<String, Object> meta) {
+        realFolder.setMeta(meta);
+    }
+
+    @Override
+    public Map<String, Object> getMeta() {
+        return realFolder.getMeta();
+    }
+
     private static Date cloneDate(final Date d) {
         if (null == d) {
             return null;
@@ -449,4 +464,15 @@ public final class OutlookFolder implements FolderExtension {
         return new Date(d.getTime());
     }
 
+    @Override
+    public Set<String> getSupportedCapabilities() {
+        return realFolder.getSupportedCapabilities();
+    }
+
+    @Override
+    public void setSupportedCapabilities(Set<String> capabilities) {
+        realFolder.setSupportedCapabilities(capabilities);
+
+    }
+
 }
