@@ -1,6 +1,5 @@
 /*
  *
-
  *    OPEN-XCHANGE legal information
  *
  *    All intellectual property rights in the Software are protected by
@@ -29,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2013 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,20 +50,25 @@
 package com.openexchange.groupware.infostore;
 
 import java.io.InputStream;
+import java.util.List;
+import java.util.Map;
 import com.openexchange.exception.OXException;
+import com.openexchange.file.storage.FileStorageFileAccess;
+import com.openexchange.file.storage.Quota;
+import com.openexchange.file.storage.Quota.Type;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.infostore.utils.Metadata;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.results.Delta;
 import com.openexchange.groupware.results.TimedResult;
-import com.openexchange.groupware.userconfiguration.UserConfiguration;
+import com.openexchange.groupware.userconfiguration.UserPermissionBits;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.session.SessionHolder;
 import com.openexchange.tx.TransactionAware;
 
 /**
  * {@link InfostoreFacade} - Access to infostore documents.
- * 
+ *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a> Some JavaDoc
  */
@@ -84,37 +88,37 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Checks if denoted document exists.
-     * 
+     *
      * @param id The identifier
      * @param version The version
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return <code>true</code> if exists; otherwise <code>false</code>
      * @throws OXException If checking for existence fails
      * @see #CURRENT_VERSION
      */
-    public boolean exists(int id, int version, Context ctx, User user, UserConfiguration userConfig) throws OXException;
+    public boolean exists(int id, int version, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
 
     /**
      * Gets the denoted document's meta data information.
-     * 
+     *
      * @param id The identifier
      * @param version The version
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return The meta data
      * @throws OXException If operation fails
      * @see #CURRENT_VERSION
      */
-    public DocumentMetadata getDocumentMetadata(int id, int version, Context ctx, User user, UserConfiguration userConfig) throws OXException;
+    public DocumentMetadata getDocumentMetadata(int id, int version, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
 
     /**
      * Saves given document meta data.
      * <p>
      * <b>Note</b>: No <tt>modifiedColumns</tt> means all columns.
-     * 
+     *
      * @param document The meta data of the document
      * @param sequenceNumber The sequence number; e.g. client most recent time stamp
      * @param session The session
@@ -124,7 +128,7 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Saves given document meta data
-     * 
+     *
      * @param document The meta data of the document
      * @param sequenceNumber The sequence number; e.g. client most recent time stamp
      * @param modifiedColumns The columns to modify
@@ -135,21 +139,21 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Gets the document's binary content.
-     * 
+     *
      * @param id The identifier
      * @param version The version
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return The document's binary content
      * @throws OXException If retrieving binary content fails
      * @see #CURRENT_VERSION
      */
-    public InputStream getDocument(int id, int version, Context ctx, User user, UserConfiguration userConfig) throws OXException;
+    public InputStream getDocument(int id, int version, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
 
     /**
      * Saves given document meta data and binary content (if not <code>null</code>).
-     * 
+     *
      * @param document The document meta data
      * @param data The optional binary content or <code>null</code>
      * @param sequenceNumber The sequence number; e.g. client most recent time stamp
@@ -160,7 +164,7 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Saves given document meta data and binary content (if not <code>null</code>).
-     * 
+     *
      * @param document The document meta data
      * @param data The optional binary content or <code>null</code>
      * @param sequenceNumber The sequence number; e.g. client most recent time stamp
@@ -172,7 +176,7 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Saves given document meta data and binary content (if not <code>null</code>).
-     * 
+     *
      * @param document The document meta data
      * @param data The optional binary content or <code>null</code>
      * @param sequenceNumber The sequence number; e.g. client most recent time stamp
@@ -185,7 +189,7 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Removes all documents contained in specified folder.
-     * 
+     *
      * @param folderId The identifier of the folder to clear
      * @param date The client's time stamp
      * @param session The session
@@ -195,7 +199,7 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Removes denoted documents.
-     * 
+     *
      * @param ids The identifiers of the documents to remove
      * @param date The client's time stamp
      * @param session The session
@@ -206,7 +210,7 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Removes denoted versions.
-     * 
+     *
      * @param id The document identifier
      * @param versionIds The identifiers of the versions to remove
      * @param session The session
@@ -217,115 +221,115 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Gets the folder's documents.
-     * 
+     *
      * @param folderId The folder identifier
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return The folder's documents
      * @throws OXException If retrieval fails
      */
-    public TimedResult<DocumentMetadata> getDocuments(long folderId, Context ctx, User user, UserConfiguration userConfig) throws OXException;
+    public TimedResult<DocumentMetadata> getDocuments(long folderId, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
 
     /**
      * Gets the folder's documents.
-     * 
+     *
      * @param folderId The folder identifier
      * @param columns The columns to set in returned documents
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return The folder's documents
      * @throws OXException If retrieval fails
      */
-    public TimedResult<DocumentMetadata> getDocuments(long folderId, Metadata[] columns, Context ctx, User user, UserConfiguration userConfig) throws OXException;
+    public TimedResult<DocumentMetadata> getDocuments(long folderId, Metadata[] columns, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
 
     /**
      * Gets the sorted folder's documents.
-     * 
+     *
      * @param folderId The folder identifier
      * @param columns The columns to set in returned documents
      * @param sort The sort-by field
      * @param order The order; see {@link #ASC} or {@link #DESC}
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return The folder's documents
      * @throws OXException If retrieval fails
      */
-    public TimedResult<DocumentMetadata> getDocuments(long folderId, Metadata[] columns, Metadata sort, int order, Context ctx, User user, UserConfiguration userConfig) throws OXException;
+    public TimedResult<DocumentMetadata> getDocuments(long folderId, Metadata[] columns, Metadata sort, int order, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
 
     /**
      * Gets the document's versions.
-     * 
+     *
      * @param id The document identifier
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return The document's version
      * @throws OXException If retrieval fails
      */
-    public TimedResult<DocumentMetadata> getVersions(int id, Context ctx, User user, UserConfiguration userConfig) throws OXException;
+    public TimedResult<DocumentMetadata> getVersions(int id, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
 
     /**
      * Gets the document's versions.
-     * 
+     *
      * @param id The document identifier
      * @param columns The columns to set in returned documents
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return The document's versions
      * @throws OXException If retrieval fails
      */
-    public TimedResult<DocumentMetadata> getVersions(int id, Metadata[] columns, Context ctx, User user, UserConfiguration userConfig) throws OXException;
+    public TimedResult<DocumentMetadata> getVersions(int id, Metadata[] columns, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
 
     /**
      * Gets the document's versions.
-     * 
+     *
      * @param id The document identifier
      * @param columns The columns to set in returned documents
      * @param sort The sort-by field
      * @param order The order; see {@link #ASC} or {@link #DESC}
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return The document's versions
      * @throws OXException If retrieval fails
      */
-    public TimedResult<DocumentMetadata> getVersions(int id, Metadata[] columns, Metadata sort, int order, Context ctx, User user, UserConfiguration userConfig) throws OXException;
+    public TimedResult<DocumentMetadata> getVersions(int id, Metadata[] columns, Metadata sort, int order, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
 
     /**
      * Gets the specified documents.
-     * 
+     *
      * @param ids The identifiers
      * @param columns The columns to set in returned documents
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return The documents
      * @throws OXException If retrieval fails
      */
-    public TimedResult<DocumentMetadata> getDocuments(int[] ids, Metadata[] columns, Context ctx, User user, UserConfiguration userConfig) throws IllegalAccessException, OXException;
+    public TimedResult<DocumentMetadata> getDocuments(int[] ids, Metadata[] columns, Context ctx, User user, UserPermissionBits userPermissons) throws IllegalAccessException, OXException;
 
     /**
      * Gets the folder's updated & deleted documents.
-     * 
+     *
      * @param folderId The folder identifier
      * @param updateSince The time stamp to consider
      * @param columns The columns to set in returned documents
      * @param ignoreDeleted Whether to ignore deleted ones
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return The matching changed/deleted documents
      * @throws OXException If retrieval fails
      */
-    public Delta<DocumentMetadata> getDelta(long folderId, long updateSince, Metadata[] columns, boolean ignoreDeleted, Context ctx, User user, UserConfiguration userConfig) throws OXException;
+    public Delta<DocumentMetadata> getDelta(long folderId, long updateSince, Metadata[] columns, boolean ignoreDeleted, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
 
     /**
      * Gets the folder's updated & deleted documents.
-     * 
+     *
      * @param folderId The folder identifier
      * @param updateSince The time stamp to consider
      * @param columns The columns to set in returned documents
@@ -334,39 +338,53 @@ public interface InfostoreFacade extends TransactionAware {
      * @param ignoreDeleted Whether to ignore deleted ones
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return The matching changed/deleted documents
      * @throws OXException If retrieval fails
      */
-    public Delta<DocumentMetadata> getDelta(long folderId, long updateSince, Metadata[] columns, Metadata sort, int order, boolean ignoreDeleted, Context ctx, User user, UserConfiguration userConfig) throws OXException;
+    public Delta<DocumentMetadata> getDelta(long folderId, long updateSince, Metadata[] columns, Metadata sort, int order, boolean ignoreDeleted, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
+
+    /**
+     * Gets the sequence numbers for the contents of the supplied folders to quickly determine which folders contain changes. An updated
+     * sequence number in a folder indicates a change, for example a new, modified or deleted file.
+     *
+     * @param folderIds A list of folder IDs to get the sequence numbers for
+     * @param versionsOnly <code>true</code> to only take documents with at least one version into account, <code>false</code>, otherwise
+     * @param ctx The context
+     * @param user The user
+     * @param userPermissions The user permissions
+     * @return A map holding the resulting sequence numbers to each requested folder ID
+     * @throws OXException
+     */
+    Map<Long, Long> getSequenceNumbers(List<Long> folderIds, boolean versionsOnly, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
 
     /**
      * Gets the number of documents in given folder.
-     * 
+     *
      * @param folderId The folder identifier
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return The number of documents
      * @throws OXException If operation fails
      */
-    public int countDocuments(long folderId, Context ctx, User user, UserConfiguration userConfig) throws OXException;
+    public int countDocuments(long folderId, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
 
     /**
      * Signals if denoted folder contains documents not owned by specified user.
-     * 
+     *
      * @param folderId The folder identifier
      * @param ctx The context
      * @param user The user
-     * @param userConfig The user configuration
+     * @param userPermissions The user permissions
      * @return <code>true</code> if folder contains documents not owned by specified user; otherwise <code>false</code>
      * @throws OXException If operation fails
      */
-    public boolean hasFolderForeignObjects(long folderId, Context ctx, User user, UserConfiguration userConfig) throws OXException;
+    public boolean hasFolderForeignObjects(long folderId, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
 
     /**
      * Checks if denoted folder is empty.
-     * 
+     *
      * @param folderId The folder identifier
      * @param ctx The context
      * @return <code>true</code> if empty; otherwise <code>false</code>
@@ -376,7 +394,7 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Performs necessary clean-up operations if specified user has been deleted.
-     * 
+     *
      * @param userId The user identifier
      * @param context The context
      * @param session The session
@@ -386,7 +404,7 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Unlocks specified document.
-     * 
+     *
      * @param id The document identifier
      * @param session The session
      * @throws OXException If operation fails
@@ -395,7 +413,7 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Locks specified document.
-     * 
+     *
      * @param id The document identifier
      * @param session The session
      * @throws OXException If operation fails
@@ -404,7 +422,7 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Touches specified document.
-     * 
+     *
      * @param id The document identifier
      * @param session The session
      * @throws OXException If operation fails
@@ -413,9 +431,54 @@ public interface InfostoreFacade extends TransactionAware {
 
     /**
      * Sets this facade's session holder.
-     * 
+     *
      * @param sessionHolder The session holder
      */
     public void setSessionHolder(SessionHolder sessionHolder);
 
+    /**
+     * Gets the quota restrictions and current usage of {@link Type#FILE} for the supplied session.
+     *
+     * @param session The session
+     * @return The quota of {@link Type#FILE}, or quota with {@link Quota#UNLIMITED} limit if not set
+     * @throws OXException
+     */
+    Quota getFileQuota(ServerSession session) throws OXException;
+
+    /**
+     * Gets the quota restrictions and current usage of {@link Type#STORAGE} for the supplied session.
+     *
+     * @param session The session
+     * @return The quota of {@link Type#STORAGE}, or quota with {@link Quota#UNLIMITED} limit if not set
+     * @throws OXException
+     */
+    Quota getStorageQuota(ServerSession session) throws OXException;
+
+    /**
+     * Loads (part of) a document's content.
+     *
+     * @param id The ID of the document
+     * @param version The version of the document. Pass {@link FileStorageFileAccess#CURRENT_VERSION} for the current version.
+     * @param offset The start offset in bytes to read from the document, or <code>0</code> to start from the beginning
+     * @param length The number of bytes to read from the document, or <code>-1</code> to read the stream until the end
+     * @param ctx The context
+     * @param user The user
+     * @param userPermissions The user permissions
+     * @return An input stream for the content
+     * @throws OXException
+     */
+    InputStream getDocument(int id, int version, long offset, long length, Context ctx, User user, UserPermissionBits userPermissons) throws OXException;
+
+    /**
+     * Save file metadata and content. Since the actual version is modified, the version number is not increased.
+     *
+     * @param document The metadata to save
+     * @param data The binary content
+     * @param sequenceNumber The sequence number to catch concurrent modification. May pass DISTANT_FUTURE to circumvent the check
+     * @param modifiedColumns The fields to save. All other fields will be ignored
+     * @param offset The start offset in bytes where to append the data to the document, must be equal to the actual document's length
+     * @param session The session
+     * @throws OXException If operation fails
+     */
+    void saveDocument(DocumentMetadata document, InputStream data, long sequenceNumber, Metadata[] modifiedColumns, long offset, ServerSession session) throws OXException;
 }
