@@ -49,8 +49,11 @@
 
 package com.openexchange.groupware.ldap;
 
+import java.util.Collections;
+import java.util.HashMap;
 import java.util.Locale;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.Set;
 import javax.mail.internet.idn.IDNA;
 import com.openexchange.i18n.LocaleTools;
@@ -101,7 +104,7 @@ public class UserImpl implements User, Cloneable {
     /**
      * User attributes
      */
-    private Map<String, Set<String>> attributes;
+    private Map<String, UserAttribute> attributes;
 
     /**
      * E-Mail domain.
@@ -530,7 +533,18 @@ public class UserImpl implements User, Cloneable {
 
     @Override
     public Map<String, Set<String>> getAttributes() {
-        return attributes;
+        if (null == attributes) {
+            return null;
+        }
+        Map<String, Set<String>> retval = new HashMap<String, Set<String>>();
+        for (Entry<String, UserAttribute> entry : attributes.entrySet()) {
+            retval.put(entry.getKey(), entry.getValue().getStringValues());
+        }
+        return Collections.unmodifiableMap(retval);
+    }
+
+    Map<String, UserAttribute> getAttributesInternal() {
+        return Collections.unmodifiableMap(attributes);
     }
 
     /**
@@ -539,6 +553,18 @@ public class UserImpl implements User, Cloneable {
      * @param attributes The attributes to set as an unmodifiable map
      */
     public void setAttributes(final Map<String, Set<String>> attributes) {
+        this.attributes = toInternal(attributes);
+    }
+
+    public static Map<String, UserAttribute> toInternal(Map<String, Set<String>> attributes) {
+        Map<String, UserAttribute> retval = new HashMap<String, UserAttribute>();
+        for (Entry<String, Set<String>> entry : attributes.entrySet()) {
+            retval.put(entry.getKey(), new UserAttribute(entry.getKey(), entry.getValue()));
+        }
+        return retval;
+    }
+
+    void setAttributesInternal(Map<String, UserAttribute> attributes) {
         this.attributes = attributes;
     }
 
