@@ -52,12 +52,11 @@ package com.openexchange.groupware.notify;
 import java.io.File;
 import java.util.HashMap;
 import java.util.Map;
-
 import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.configuration.ConfigurationExceptionCodes;
 import com.openexchange.exception.OXException;
+import com.openexchange.log.LogFactory;
 import com.openexchange.server.Initialization;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.tools.conf.AbstractConfig;
@@ -119,7 +118,7 @@ public class NotificationConfig extends AbstractConfig implements Initialization
             try {
                 INSTANCE.loadPropertiesInternal();
             } catch (final OXException e) {
-                LOG.error(e);
+                LOG.error(e.getMessage(), e);
                 return def;
             }
         }
