@@ -331,6 +331,7 @@ public final class ConfigTree {
             com.openexchange.groupware.settings.tree.modules.mail.DefaultSeparator.class,
             com.openexchange.groupware.settings.tree.modules.mail.DeleteMail.class,
             com.openexchange.groupware.settings.tree.modules.mail.UnifiedInboxEnablement.class,
+            com.openexchange.groupware.settings.tree.modules.mail.UnifiedInboxIdentifier.class,
             com.openexchange.groupware.settings.tree.modules.mail.Emoticons.class,
             com.openexchange.groupware.settings.tree.modules.mail.folder.Drafts.class,
             com.openexchange.groupware.settings.tree.modules.mail.folder.Inbox.class,
@@ -380,6 +381,7 @@ public final class ConfigTree {
             com.openexchange.groupware.settings.tree.TimeZone.class,
             com.openexchange.groupware.settings.tree.LocationLogout.class,
             com.openexchange.groupware.settings.tree.LocationError.class,
+            com.openexchange.groupware.settings.tree.ValidateContactEmail.class,
         };
     }
 
