@@ -49,20 +49,60 @@
 
 package com.openexchange.groupware.update.internal;
 
+import java.util.ArrayList;
+import java.util.List;
 import org.apache.commons.logging.Log;
+import com.openexchange.groupware.update.FullPrimaryKeySupportService;
 import com.openexchange.groupware.update.UpdateTask;
 import com.openexchange.groupware.update.UpdateTaskAdapter;
 import com.openexchange.groupware.update.UpdateTaskV2;
+import com.openexchange.groupware.update.tasks.AddPrimaryKeyVcardIdsTask;
+import com.openexchange.groupware.update.tasks.AddPrimaryKeyVcardPrincipalTask;
+import com.openexchange.groupware.update.tasks.AddUUIDForDListTables;
+import com.openexchange.groupware.update.tasks.AddUUIDForInfostoreReservedPaths;
+import com.openexchange.groupware.update.tasks.AddUUIDForUpdateTaskTable;
+import com.openexchange.groupware.update.tasks.AddUUIDForUserAttributeTable;
 import com.openexchange.groupware.update.tasks.AllowTextInValuesOfDynamicContextAttributesTask;
 import com.openexchange.groupware.update.tasks.AllowTextInValuesOfDynamicUserAttributesTask;
 import com.openexchange.groupware.update.tasks.CorrectAttachmentCountInAppointments;
 import com.openexchange.groupware.update.tasks.CorrectFileAsInContacts;
 import com.openexchange.groupware.update.tasks.CorrectOrganizerInAppointments;
+import com.openexchange.groupware.update.tasks.CreateIcalIdsPrimaryKeyTask;
+import com.openexchange.groupware.update.tasks.CreateIcalPrincipalPrimaryKeyTask;
 import com.openexchange.groupware.update.tasks.CreateIndexOnContextAttributesTask;
 import com.openexchange.groupware.update.tasks.CreateIndexOnUserAttributesForAliasLookupTask;
+import com.openexchange.groupware.update.tasks.DateExternalCreateForeignKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.DateExternalDropForeignKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.DelDateExternalCreateForeignKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.DelDateExternalDropForeignKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.DelDatesMembersPrimaryKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.DelDatesPrimaryKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.DelInfostorePrimaryKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.GenconfAttributesBoolsAddPrimaryKey;
+import com.openexchange.groupware.update.tasks.GenconfAttributesBoolsAddUuidUpdateTask;
+import com.openexchange.groupware.update.tasks.GenconfAttributesStringsAddPrimaryKey;
+import com.openexchange.groupware.update.tasks.GenconfAttributesStringsAddUuidUpdateTask;
+import com.openexchange.groupware.update.tasks.InfostoreDocumentCreateForeignKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.InfostoreDocumentDropForeignKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.InfostorePrimaryKeyUpdateTask;
 import com.openexchange.groupware.update.tasks.MailAccountAddReplyToTask;
+import com.openexchange.groupware.update.tasks.MakeFolderIdPrimaryForDelContactsTable;
+import com.openexchange.groupware.update.tasks.MakeUUIDPrimaryForDListTables;
+import com.openexchange.groupware.update.tasks.MakeUUIDPrimaryForInfostoreReservedPaths;
+import com.openexchange.groupware.update.tasks.MakeUUIDPrimaryForUpdateTaskTable;
+import com.openexchange.groupware.update.tasks.MakeUUIDPrimaryForUserAttributeTable;
+import com.openexchange.groupware.update.tasks.PrgContactsLinkageAddPrimaryKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.PrgContactsLinkageAddUuidUpdateTask;
+import com.openexchange.groupware.update.tasks.PrgDatesMembersPrimaryKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.PrgDatesPrimaryKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.PrgLinksAddPrimaryKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.PrgLinksAddUuidUpdateTask;
+import com.openexchange.groupware.update.tasks.RemoveRedundantKeysForBug26913UpdateTask;
+import com.openexchange.groupware.update.tasks.UserSettingServerAddPrimaryKeyUpdateTask;
+import com.openexchange.groupware.update.tasks.UserSettingServerAddUuidUpdateTask;
 import com.openexchange.groupware.update.tasks.VirtualFolderAddSortNumTask;
 import com.openexchange.log.LogFactory;
+import com.openexchange.server.services.ServerServiceRegistry;
 
 /**
  * Lists all update tasks of the com.openexchange.server bundle.
@@ -75,14 +115,22 @@ public final class InternalList {
 
     private static final InternalList SINGLETON = new InternalList();
 
-    private InternalList() {
-        super();
-    }
-
+    /**
+     * Gets the {@link InternalList} instance
+     *
+     * @return The instance
+     */
     public static final InternalList getInstance() {
         return SINGLETON;
     }
 
+    private InternalList() {
+        super();
+    }
+
+    /**
+     * Starts the internal list.
+     */
     public void start() {
         final DynamicList registry = DynamicList.getInstance();
         for (final UpdateTask task : OLD_TASKS) {
@@ -90,6 +138,7 @@ public final class InternalList {
                 LOG.error("Internal update task \"" + task.getClass().getName() + "\" could not be registered.", new Exception());
             }
         }
+        TASKS = genTaskList();
         for (final UpdateTaskV2 task : TASKS) {
             if (!registry.addUpdateTask(task)) {
                 LOG.error("Internal update task \"" + task.getClass().getName() + "\" could not be registered.", new Exception());
@@ -97,6 +146,9 @@ public final class InternalList {
         }
     }
 
+    /**
+     * Stops the internal list.
+     */
     public void stop() {
         final DynamicList registry = DynamicList.getInstance();
         for (final UpdateTaskV2 task : TASKS) {
@@ -319,42 +371,46 @@ public final class InternalList {
     /**
      * All this tasks should extend {@link UpdateTaskAdapter} to fulfill the prerequisites to be sorted among their dependencies.
      */
-    private static final UpdateTaskV2[] TASKS = new UpdateTaskV2[] {
+    private static UpdateTaskV2[] TASKS = null;
+
+    private static UpdateTaskV2[] genTaskList() {
+        List<UpdateTaskV2> list = new ArrayList<UpdateTaskV2>();
+
         // Renames "Unified INBOX" to "Unified Mail"
-        new com.openexchange.groupware.update.tasks.UnifiedINBOXRenamerTask(),
+        list.add(new com.openexchange.groupware.update.tasks.UnifiedINBOXRenamerTask());
 
         // Creates necessary tables for mail header cache
-        new com.openexchange.groupware.update.tasks.HeaderCacheCreateTableTask(),
+        list.add(new com.openexchange.groupware.update.tasks.HeaderCacheCreateTableTask());
 
         // Extends the calendar tables and creates table to store the confirmation data for external participants.
-        new com.openexchange.groupware.update.tasks.ExtendCalendarForIMIPHandlingTask(),
+        list.add(new com.openexchange.groupware.update.tasks.ExtendCalendarForIMIPHandlingTask());
 
         // Enables the bit for the contact collector feature for every user because that bit was not checked before 6.16.
-        new com.openexchange.groupware.update.tasks.ContactCollectorReEnabler(),
+        list.add(new com.openexchange.groupware.update.tasks.ContactCollectorReEnabler());
 
         // +++++++++++++++++++++++++++++++++ Version 6.18 starts here. +++++++++++++++++++++++++++++++++
 
         // Adds a column to the table user_setting_server named folderTree to store the selected folder tree.
-        new com.openexchange.groupware.update.tasks.FolderTreeSelectionTask(),
+        list.add(new com.openexchange.groupware.update.tasks.FolderTreeSelectionTask());
 
         // Repairs appointments where the number of attachments does not match the real amount of attachments.
-        new com.openexchange.groupware.update.tasks.AttachmentCountUpdateTask(),
+        list.add(new com.openexchange.groupware.update.tasks.AttachmentCountUpdateTask());
 
         // Creates an initial empty filestore usage entry for every context that currently did not uploaded anything.
-        new com.openexchange.groupware.update.tasks.AddInitialFilestoreUsage(),
+        list.add(new com.openexchange.groupware.update.tasks.AddInitialFilestoreUsage());
 
         // Currently users contacts are created with the display name attribute filed. Outlook primarily uses the fileAs attribute. This
         // task copies the display name to fileAs if that is empty.
-        new com.openexchange.groupware.update.tasks.AddFileAsForUserContacts(),
+        list.add(new com.openexchange.groupware.update.tasks.AddFileAsForUserContacts());
 
         // Extend field "reason" for participants.
-        new com.openexchange.groupware.update.tasks.ParticipantCommentFieldLength(),
+        list.add(new com.openexchange.groupware.update.tasks.ParticipantCommentFieldLength());
 
         // New table for linking several appointments (from different sources) together that represent the same person.
-        new com.openexchange.groupware.update.tasks.AggregatingContactTableService(),
+        list.add(new com.openexchange.groupware.update.tasks.AggregatingContactTableService());
 
         // Creates new table for multi-purpose ID generation
-        new com.openexchange.groupware.update.tasks.IDCreateTableTask(),
+        list.add(new com.openexchange.groupware.update.tasks.IDCreateTableTask());
 
         // TODO: Enable virtual folder tree update task when needed
         // Migrates existing folder data to new outlook-like folder tree structure
@@ -363,135 +419,252 @@ public final class InternalList {
         // +++++++++++++++++++++++++++++++++ Version 6.20 starts here. +++++++++++++++++++++++++++++++++
 
         // Transforms the "info" field to a TEXT field. This fields seems not to be used anywhere.
-        new com.openexchange.groupware.update.tasks.ContactInfoField2Text(),
+        list.add(new com.openexchange.groupware.update.tasks.ContactInfoField2Text());
 
-        // Creates new Contact fields (First Name, Last Name, Company) for Kana based search in japanese environments.
-        new com.openexchange.groupware.update.tasks.ContactFieldsForJapaneseKanaSearch(),
+        // Creates new Contact fields (First Name); Last Name); Company) for Kana based search in japanese environments.
+        list.add(new com.openexchange.groupware.update.tasks.ContactFieldsForJapaneseKanaSearch());
 
         // Remove facebook subscriptions to force use of new oauth
-        new com.openexchange.groupware.update.tasks.FacebookCrawlerSubscriptionRemoverTask(),
+        list.add(new com.openexchange.groupware.update.tasks.FacebookCrawlerSubscriptionRemoverTask());
 
         // Remove linkedin subscriptions to force use of new oauth
-        new com.openexchange.groupware.update.tasks.LinkedInCrawlerSubscriptionsRemoverTask(),
+        list.add(new com.openexchange.groupware.update.tasks.LinkedInCrawlerSubscriptionsRemoverTask());
 
         // Remove yahoo subscriptions to force use of new oauth
-        new com.openexchange.groupware.update.tasks.DeleteOldYahooSubscriptions(),
+        list.add(new com.openexchange.groupware.update.tasks.DeleteOldYahooSubscriptions());
 
         // Switch the column type of 'value' in contextAttribute to TEXT
-        new AllowTextInValuesOfDynamicContextAttributesTask(),
+        list.add(new AllowTextInValuesOfDynamicContextAttributesTask());
 
         // Switch the column type of 'value' in user_attribute to TEXT
-        new AllowTextInValuesOfDynamicUserAttributesTask(),
+        list.add(new AllowTextInValuesOfDynamicUserAttributesTask());
 
         // Recreate the index on the context attributes table
-        new CreateIndexOnContextAttributesTask(),
+        list.add(new CreateIndexOnContextAttributesTask());
 
         // Recreate the index on the user attributes table for alias lookup
-        new CreateIndexOnUserAttributesForAliasLookupTask(),
+        list.add(new CreateIndexOnUserAttributesForAliasLookupTask());
 
         // Correct the attachment count in the dates table
-        new CorrectAttachmentCountInAppointments(),
+        list.add(new CorrectAttachmentCountInAppointments());
 
         // Corrects the organizer in appointments. When exporting iCal and importing it again the organizer gets value 'null' instead of SQL
         // NULL. This task corrects this.
-        new CorrectOrganizerInAppointments(),
+        list.add(new CorrectOrganizerInAppointments());
 
         // Corrects field90 aka fileAs in contacts to have proper contact names in card view of Outlook OXtender 2.
-        new CorrectFileAsInContacts(),
+        list.add(new CorrectFileAsInContacts());
 
         // Add "sortNum" column to virtual folder table.
-        new VirtualFolderAddSortNumTask(),
+        list.add(new VirtualFolderAddSortNumTask());
 
         // +++++++++++++++++++++++++++++++++ Version 6.20.1 starts here. +++++++++++++++++++++++++++++++++
 
         // Restores the initial permissions on the public root folder.
-        new com.openexchange.groupware.update.tasks.DropIndividualUserPermissionsOnPublicFolderTask(),
+        list.add(new com.openexchange.groupware.update.tasks.DropIndividualUserPermissionsOnPublicFolderTask());
 
         // Adds Outlook address fields to contact tables
-        new com.openexchange.groupware.update.tasks.ContactAddOutlookAddressFieldsTask(),
+        list.add(new com.openexchange.groupware.update.tasks.ContactAddOutlookAddressFieldsTask());
 
         // Add UID field to contact tables.
-        new com.openexchange.groupware.update.tasks.ContactAddUIDFieldTask(),
+        list.add(new com.openexchange.groupware.update.tasks.ContactAddUIDFieldTask());
 
         // Add UIDs to contacts if missing
-        new com.openexchange.groupware.update.tasks.ContactAddUIDValueTask(),
+        list.add(new com.openexchange.groupware.update.tasks.ContactAddUIDValueTask());
 
         // Adds UIDs to tasks.
-        new com.openexchange.groupware.update.tasks.TasksAddUidColumnTask(),
+        list.add(new com.openexchange.groupware.update.tasks.TasksAddUidColumnTask());
 
         // Adds UID indexes.
-        new com.openexchange.groupware.update.tasks.CalendarAddUIDIndexTask(),
+        list.add(new com.openexchange.groupware.update.tasks.CalendarAddUIDIndexTask());
 
         // Drops rather needless foreign keys
-        new com.openexchange.groupware.update.tasks.DropFKTask(),
+        list.add(new com.openexchange.groupware.update.tasks.DropFKTask());
 
-        // Adds 'organizerId', 'principal' and 'principalId' to prg_dates and del_dates
-        new com.openexchange.groupware.update.tasks.AppointmentAddOrganizerIdPrincipalPrincipalIdColumnsTask(),
+        // Adds 'organizerId'); 'principal' and 'principalId' to prg_dates and del_dates
+        list.add(new com.openexchange.groupware.update.tasks.AppointmentAddOrganizerIdPrincipalPrincipalIdColumnsTask());
 
         // Adds index to prg_dates_members and del_dates_members
-        new com.openexchange.groupware.update.tasks.CalendarAddIndex2DatesMembers(),
+        list.add(new com.openexchange.groupware.update.tasks.CalendarAddIndex2DatesMembers());
 
         // Adds index to oxfolder_tree and del_oxfolder_tree
-        new com.openexchange.groupware.update.tasks.FolderAddIndex2LastModified(),
+        list.add(new com.openexchange.groupware.update.tasks.FolderAddIndex2LastModified());
 
         // Checks for missing folder 'public_infostore' (15) in any available context
-        new com.openexchange.groupware.update.tasks.CheckForPublicInfostoreFolderTask(),
+        list.add(new com.openexchange.groupware.update.tasks.CheckForPublicInfostoreFolderTask());
 
         // Drops useless foreign keys from 'malPollHash' table
-        new com.openexchange.groupware.update.tasks.MALPollDropConstraintsTask(),
+        list.add( new com.openexchange.groupware.update.tasks.MALPollDropConstraintsTask());
 
         // +++++++++++++++++++++++++++++++++ Version 6.20.3 starts here. +++++++++++++++++++++++++++++++++
 
         // Extends dn fields in calendar tables to 320 chars.
-        new com.openexchange.groupware.update.tasks.CalendarExtendDNColumnTaskV2(),
+        list.add(new com.openexchange.groupware.update.tasks.CalendarExtendDNColumnTaskV2());
 
         // +++++++++++++++++++++++++++++++++ Version 6.20.5 starts here. +++++++++++++++++++++++++++++++++
 
         // Creates indexes on tables "prg_dlist" and "del_dlist" to improve look-up.
-        new com.openexchange.groupware.update.tasks.DListAddIndexForLookup(),
+        list.add(new com.openexchange.groupware.update.tasks.DListAddIndexForLookup());
 
         // +++++++++++++++++++++++++++++++++ Version 6.20.7 starts here. +++++++++++++++++++++++++++++++++
 
-        // Another attempt: Adds 'organizerId', 'principal' and 'principalId' to prg_dates and del_dates
-        new com.openexchange.groupware.update.tasks.AppointmentAddOrganizerIdPrincipalPrincipalIdColumnsTask2(),
+        // Another attempt: Adds 'organizerId'); 'principal' and 'principalId' to prg_dates and del_dates
+        list.add(new com.openexchange.groupware.update.tasks.AppointmentAddOrganizerIdPrincipalPrincipalIdColumnsTask2());
 
         // Add UIDs to appointments if missing.
-        new com.openexchange.groupware.update.tasks.CalendarAddUIDValueTask(),
+        list.add(new com.openexchange.groupware.update.tasks.CalendarAddUIDValueTask());
 
         // +++++++++++++++++++++++++++++++++ Version 6.22.0 starts here. +++++++++++++++++++++++++++++++++
 
         // Add "replyTo" column to mail/transport account table
-        new MailAccountAddReplyToTask(),
+        list.add(new MailAccountAddReplyToTask());
 
         // Migrate "replyTo" information from properties table to account tables
-        new com.openexchange.groupware.update.tasks.MailAccountMigrateReplyToTask(),
+        list.add(new com.openexchange.groupware.update.tasks.MailAccountMigrateReplyToTask());
 
         // Add 'filename' column to appointment tables.
-        new com.openexchange.groupware.update.tasks.AppointmentAddFilenameColumnTask(),
+        list.add(new com.openexchange.groupware.update.tasks.AppointmentAddFilenameColumnTask());
 
         // Add 'filename' column to task tables.
-        new com.openexchange.groupware.update.tasks.TasksAddFilenameColumnTask(),
+        list.add(new com.openexchange.groupware.update.tasks.TasksAddFilenameColumnTask());
 
         // Removes unnecessary indexes from certain tables (see Bug #21882)
-        new com.openexchange.groupware.update.tasks.RemoveUnnecessaryIndexes(),
-        new com.openexchange.groupware.update.tasks.RemoveUnnecessaryIndexes2(),
+        list.add(new com.openexchange.groupware.update.tasks.RemoveUnnecessaryIndexes());
+        list.add(new com.openexchange.groupware.update.tasks.RemoveUnnecessaryIndexes2());
 
         // +++++++++++++++++++++++++++++++++ Version 6.22.1 starts here. +++++++++++++++++++++++++++++++++
-        new com.openexchange.groupware.update.tasks.ContactFixUserDistListReferencesTask(),
+        list.add(new com.openexchange.groupware.update.tasks.ContactFixUserDistListReferencesTask());
 
         // +++++++++++++++++++++++++++++++++ Version 7.0.0 starts here. +++++++++++++++++++++++++++++++++
 
         // Extends the resources' description field
-        new com.openexchange.groupware.update.tasks.EnlargeResourceDescription(),
+        list.add(new com.openexchange.groupware.update.tasks.EnlargeResourceDescription());
 
         // Extends the UID field
-        new com.openexchange.groupware.update.tasks.EnlargeCalendarUid(),
+        list.add(new com.openexchange.groupware.update.tasks.EnlargeCalendarUid());
 
         // Sets the changing date once for users with a different defaultSendAddress
-        new com.openexchange.groupware.update.tasks.ContactAdjustLastModifiedForChangedSenderAddress(),
+        list.add(new com.openexchange.groupware.update.tasks.ContactAdjustLastModifiedForChangedSenderAddress());
 
         // Drop foreign key constraints from obsolete tables
-        new com.openexchange.groupware.update.tasks.HeaderCacheDropFKTask(),
+        list.add(new com.openexchange.groupware.update.tasks.HeaderCacheDropFKTask());
 
-    };
+        // +++++++++++++++++++++++++++++++++ Version 7.4.0 starts here. +++++++++++++++++++++++++++++++++
+
+        // Add UUID column to genconf_attributes_strings table
+        list.add(new GenconfAttributesStringsAddUuidUpdateTask());
+
+        // Add UUID column to genconf_attributes_bools table
+        list.add(new GenconfAttributesBoolsAddUuidUpdateTask());
+
+        // Add UUID column to updatTask table
+        list.add(new AddUUIDForUpdateTaskTable());
+
+        //Add Uuid column to prg_links table
+        list.add(new PrgLinksAddUuidUpdateTask());
+
+        //Add Uuid column to prg_contacts_linkage table
+        list.add(new PrgContactsLinkageAddUuidUpdateTask());
+
+        //Add Uuid column to dlist tables
+        list.add(new AddUUIDForDListTables());
+
+        //Add primary key to ical_ids table
+        list.add(new CreateIcalIdsPrimaryKeyTask());
+
+        //Add primary key to ical_principal table
+        list.add(new CreateIcalPrincipalPrimaryKeyTask());
+
+        //Add primary key to vcard_ids table
+        list.add(new AddPrimaryKeyVcardIdsTask());
+
+        //Add primary key to vcard_principal table
+        list.add(new AddPrimaryKeyVcardPrincipalTask());
+
+        // Add UUID column to user_attribute table
+        list.add(new AddUUIDForUserAttributeTable());
+
+        //Add UUID column to infostoreReservedPaths table
+        list.add(new AddUUIDForInfostoreReservedPaths());
+
+        //Add UUID column to user_setting_server table
+        list.add(new UserSettingServerAddUuidUpdateTask());
+        
+        //Drop foreign key from infostore_document table
+        list.add(new InfostoreDocumentDropForeignKeyUpdateTask());
+        
+        //Add folder_id to primary key in infostore table
+        list.add(new InfostorePrimaryKeyUpdateTask());
+        
+        //Add foreign key to infostore_document_table
+        list.add(new InfostoreDocumentCreateForeignKeyUpdateTask());
+
+        //Add folder_id to primary key in del_infostore table
+        list.add(new DelInfostorePrimaryKeyUpdateTask());
+        
+        //Drop foreign key from dateExternal table
+        list.add(new DateExternalDropForeignKeyUpdateTask());
+
+        //Add folder_id to primary key in prg_dates
+        list.add(new PrgDatesPrimaryKeyUpdateTask());
+        
+        //Create foreign key in dateExternal table
+        list.add(new DateExternalCreateForeignKeyUpdateTask());
+        
+        //Drop foreign key from delDateExternal table
+        list.add(new DelDateExternalDropForeignKeyUpdateTask());
+        
+        //Add folder_id to primary key in del_dates
+        list.add(new DelDatesPrimaryKeyUpdateTask());
+        
+        //Create foreign key in delDateExternal table
+        list.add(new DelDateExternalCreateForeignKeyUpdateTask());
+
+        // Add folder_id to primary key in del_contacts
+        list.add(new MakeFolderIdPrimaryForDelContactsTable());
+        
+        // Remove redundant keys (see bug 26913)
+        list.add(new RemoveRedundantKeysForBug26913UpdateTask());
+
+        // Add synthetic primary keys to tables without natural key if full primary key support is enabled
+        final FullPrimaryKeySupportService fullPrimaryKeySupportService = ServerServiceRegistry.getInstance().getService(FullPrimaryKeySupportService.class);
+        if (fullPrimaryKeySupportService.isFullPrimaryKeySupported()) {
+
+            // Add primary key to genconf_attributes_strings table
+            list.add(new GenconfAttributesStringsAddPrimaryKey());
+
+            // Add primary key to genconf_attributes_bools table
+            list.add(new GenconfAttributesBoolsAddPrimaryKey());
+
+            // Add primary key to updateTask table
+            list.add(new MakeUUIDPrimaryForUpdateTaskTable());
+
+            // Add primary key to user_attribute table
+            list.add(new MakeUUIDPrimaryForUserAttributeTable());
+
+            //Add primary key to prg_links table
+            list.add(new PrgLinksAddPrimaryKeyUpdateTask());
+
+            //Add primary key to prg_contacts_linkage table
+            list.add(new PrgContactsLinkageAddPrimaryKeyUpdateTask());
+
+            //Add primary key to dlist tables
+            list.add(new MakeUUIDPrimaryForDListTables());
+
+            //Add primary key to infostoreReservedPaths table;
+            list.add(new MakeUUIDPrimaryForInfostoreReservedPaths());
+
+            //Add primary key to user_setting_server table
+            list.add(new UserSettingServerAddPrimaryKeyUpdateTask());
+            
+            //Add folder_id to primary key in prg_dates_members
+            list.add(new PrgDatesMembersPrimaryKeyUpdateTask());
+            
+            //Add folder_id to primary key in del_dates_members
+            list.add(new DelDatesMembersPrimaryKeyUpdateTask());
+
+        }
+
+        return list.toArray(new UpdateTaskV2[list.size()]);
+    }
 }
