@@ -117,6 +117,7 @@ public final class UpdateTaskResetVersionCLT {
         final CommandLineParser parser = new PosixParser();
         int contextId = -1;
         String schemaName = null;
+        boolean error = true;
         try {
             final CommandLine cmd = parser.parse(toolkitOptions, args);
             if (cmd.hasOption('h')) {
@@ -132,12 +133,12 @@ public final class UpdateTaskResetVersionCLT {
                     } catch (final NumberFormatException e) {
                         System.err.println("Port parameter is not a number: " + val);
                         printHelp();
-                        System.exit(0);
+                        System.exit(1);
                     }
                     if (port < 1 || port > 65535) {
                         System.err.println("Port parameter is out of range: " + val + ". Valid range is from 1 to 65535.");
                         printHelp();
-                        System.exit(0);
+                        System.exit(1);
                     }
                 }
             }
@@ -145,14 +146,14 @@ public final class UpdateTaskResetVersionCLT {
             if (!cmd.hasOption('v')) {
                 System.err.println("Missing version number.");
                 printHelp();
-                System.exit(0);
+                System.exit(1);
             } else {
                 final String optionValue = cmd.getOptionValue('v');
                 try {
                     version = Integer.parseInt(optionValue.trim());
                 } catch (final NumberFormatException e) {
                     System.err.println("Port parameter is not a number: " + optionValue);
-                    System.exit(0);
+                    System.exit(1);
                 }
             }
 
@@ -160,7 +161,7 @@ public final class UpdateTaskResetVersionCLT {
                 if (!cmd.hasOption('n')) {
                     System.err.println("Missing context/schema identifier.");
                     printHelp();
-                    System.exit(0);
+                    System.exit(1);
                 }
                 schemaName = cmd.getOptionValue('n');
             } else {
@@ -170,7 +171,7 @@ public final class UpdateTaskResetVersionCLT {
                 } catch (final NumberFormatException e) {
                     System.err.println("Context parameter is not a number: " + optionValue);
                     printHelp();
-                    System.exit(0);
+                    System.exit(1);
                 }
             }
 
@@ -204,9 +205,16 @@ public final class UpdateTaskResetVersionCLT {
                 }
 
             } finally {
-                Streams.close(jmxConnector);
+                if (null != jmxConnector) {
+                    try {
+                        jmxConnector.close();
+                    } catch (final Exception e) {
+                        // Ignore
+                    }
+                }
             }
 
+            error = false;
         } catch (final ParseException e) {
             System.err.println("Unable to parse command line: " + e.getMessage());
             printHelp();
@@ -234,6 +242,10 @@ public final class UpdateTaskResetVersionCLT {
         } catch (final RuntimeException e) {
             System.err.println("Problem in runtime: " + e.getMessage());
             printHelp();
+        } finally {
+            if (error) {
+                System.exit(1);
+            }
         }
     }
 
