@@ -55,6 +55,9 @@ import com.openexchange.api2.MailInterfaceMonitor;
 import com.openexchange.exception.OXException;
 import com.openexchange.filemanagement.ManagedFile;
 import com.openexchange.groupware.importexport.MailImportResult;
+import com.openexchange.mail.api.IMailFolderStorage;
+import com.openexchange.mail.api.IMailMessageStorage;
+import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.api.MailConfig;
 import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mail.dataobjects.MailFolderDescription;
@@ -481,6 +484,11 @@ public abstract class MailServletInterface {
      */
     public abstract MailConfig getMailConfig() throws OXException;
 
+    /**
+     * Returns user-specific mail access
+     */
+    public abstract MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> getMailAccess() throws OXException;
+
     /**
      * Gets the account ID to which the (primary) mail access is connected
      *
