@@ -232,7 +232,7 @@ public final class InlineImageDataSource implements ImageDataSource {
                  * Either general purpose "application/octet-stream" or check by file name
                  */
                 if (null == fileName) {
-                    if (!contentType.isMimeType(MimeTypes.MIME_APPL_OCTET)) {
+                    if (!contentType.startsWith(MimeTypes.MIME_APPL_OCTET)) {
                         throw DataExceptionCodes.ERROR.create("Requested mail part is not an image: " + contentType.getBaseType());
                     }
                 } else {
@@ -243,7 +243,7 @@ public final class InlineImageDataSource implements ImageDataSource {
                          */
                         contentType.setBaseType(byFileName);
                     } else {
-                        if (!contentType.isMimeType(MimeTypes.MIME_APPL_OCTET)) {
+                        if (!contentType.startsWith(MimeTypes.MIME_APPL_OCTET)) {
                             throw DataExceptionCodes.ERROR.create("Requested mail part is not an image: " + contentType.getBaseType());
                         }
                     }
