@@ -54,6 +54,7 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.Mail;
+import com.openexchange.ajax.requesthandler.AJAXRequestDataTools;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.documentation.RequestMethod;
 import com.openexchange.documentation.annotations.Action;
@@ -120,9 +121,12 @@ public final class GetForwardAction extends AbstractMailAction {
              * Overwrite settings with request's parameters
              */
             detectDisplayMode(true, view, usmNoSave);
-            if (Boolean.parseBoolean(req.getParameter("dropPrefix"))) {
+            if (AJAXRequestDataTools.parseBoolParameter(req.getParameter("dropPrefix"))) {
                 usmNoSave.setDropReplyForwardPrefix(true);
             }
+            if (AJAXRequestDataTools.parseBoolParameter(req.getParameter("attachOriginalMessage"))) {
+                usmNoSave.setAttachOriginalMessage(true);
+            }
             /*
              * Get mail interface
              */
