@@ -347,8 +347,6 @@ public final class FolderWriter {
                     putter.put(FolderFields.OWN_RIGHTS, Integer.valueOf(permissionBits));
                 } catch (final JSONException e) {
                     throw MailExceptionCode.JSON_ERROR.create(e, e.getMessage());
-                } catch (final OXException e) {
-                    throw new OXException(e);
                 }
             }
         });
@@ -372,8 +370,6 @@ public final class FolderWriter {
                     putter.put(FolderFields.PERMISSIONS, ja);
                 } catch (final JSONException e) {
                     throw MailExceptionCode.JSON_ERROR.create(e, e.getMessage());
-                } catch (final OXException e) {
-                    throw new OXException(e);
                 }
             }
         });
@@ -386,7 +382,7 @@ public final class FolderWriter {
                      * Put value
                      */
                     final String value =
-                        folder.isRootFolder() ? "" : new StringBuilder(16).append('(').append(folder.getMessageCount()).append('/').append(
+                        folder.isRootFolder() ? "" : new com.openexchange.java.StringAllocator(16).append('(').append(folder.getMessageCount()).append('/').append(
                             folder.getUnreadMessageCount()).append(')').toString();
                     putter.put(FolderFields.SUMMARY, value);
                 } catch (final JSONException e) {
