@@ -731,6 +731,13 @@ public class ContentType extends ParameterizedHeader {
         return containsParameter(PARAM_CHARSET);
     }
 
+    /**
+     * @return The removed <code>"charset"</code> parameter value or <code>null</code> if there was none
+     */
+    public String removeCharsetParameter() {
+        return removeParameter(PARAM_CHARSET);
+    }
+
     /**
      * Sets <code>"name"</code> parameter
      *
@@ -756,6 +763,13 @@ public class ContentType extends ParameterizedHeader {
         return containsParameter(PARAM_NAME);
     }
 
+    /**
+     * @return The removed <code>"name"</code> parameter value or <code>null</code> if there was none
+     */
+    public String removeNameParameter() {
+        return removeParameter(PARAM_NAME);
+    }
+
     /**
      * Sets the content type to specified content type string; e.g. "text/plain; charset=US-ASCII"
      *
