@@ -103,13 +103,13 @@ public class MimeMailExceptionMessage implements LocalizableStrings {
      * reason. Following the exception, the Folder is reset to the "closed" state.
      * </p>
      */
-    public final static String FOLDER_CLOSED_MSG = "Folder \"%1$s\" has been closed."+LINE_SEPARATOR+"Probably your request took too long.";
+    public final static String FOLDER_CLOSED_MSG = "Folder \"%1$s\" has been closed. Probably your request took too long.";
 
     /**
      * Folder "%1$s" has been closed on mail server %2$s with login %3$s (user=%4$s, context=%5$s) due to some reason.<br>
      * Probably your request took too long.
      */
-    public final static String FOLDER_CLOSED_EXT_MSG = "Folder \"%1$s\" has been closed on mail server %2$s with login %3$s (user=%4$s, context=%5$s) ."+LINE_SEPARATOR+"Probably your request took too long.";
+    public final static String FOLDER_CLOSED_EXT_MSG = "Folder \"%1$s\" has been closed on mail server %2$s with login %3$s (user=%4$s, context=%5$s). Probably your request took too long.";
 
     /**
      * Illegal write attempt: %1$s
@@ -265,10 +265,8 @@ public class MimeMailExceptionMessage implements LocalizableStrings {
      */
     public final static String QUOTA_EXCEEDED_EXT_MSG = "The quota on mail server \"%1$s\" exceeded with login %2$s (user=%3$s, context=%4$s). Error message: %5$s";
 
-    /**
-     * A command to mail server failed. Server response: %1$s
-     */
-    public final static String COMMAND_FAILED_MSG = "A command to mail server failed. Server response: %1$s.";
+    // A command sent to mail server failed. Server response: %1$s
+    public final static String COMMAND_FAILED_MSG = "A command sent to mail server failed. Server response: %1$s";
 
     /**
      * A command failed on mail server %1$s with login %2$s (user=%3$s, context=%4$s). Server response: %5$s
@@ -290,10 +288,8 @@ public class MimeMailExceptionMessage implements LocalizableStrings {
      */
     public final static String PROTOCOL_ERROR_MSG = "Error in mail server protocol. Error message: %1$s";
 
-    /**
-     * An error in protocol to mail server %1$s with login %2$s (user=%3$s, context=%4$s). Error message: %5$s
-     */
-    public final static String PROTOCOL_ERROR_EXT_MSG = "Error in protocol to mail server %1$s with login %2$s (user=%3$s, context=%4$s). Error message: %5$s";
+    // Protocol error in data sent to the mail server %1$s with login %2$s (user=%3$s, context=%4$s). Error message: %5$s
+    public final static String PROTOCOL_ERROR_EXT_MSG = "Protocol error in data sent to the mail server %1$s with login %2$s (user=%3$s, context=%4$s). Error message: %5$s";
 
     /**
      * Message could not be sent: %1$s
@@ -352,8 +348,8 @@ public class MimeMailExceptionMessage implements LocalizableStrings {
      */
     public final static String PROCESSING_ERROR_WE_EXT_MSG = "Error processing %1$s mail server response for login %2$s (user=%3$s, context=%4$s). The administrator has been informed. Error message: %5$s";
 
-    public static final String IN_USE_ERROR_MSG = "That mailbox is already in use by another process. Please try again later." + Strings.getLineSeparator() + "Error message: %1$s";
+    public static final String IN_USE_ERROR_MSG = "That mailbox is already in use by another process. Please try again later. Error message: %1$s";
 
-    public static final String IN_USE_ERROR_EXT_MSG = "That mailbox is already in use by another process on %1$s mail server for login %2$s (user=%3$s, context=%4$s). Please try again later." + Strings.getLineSeparator() + "Error message: %5$s";;
+    public static final String IN_USE_ERROR_EXT_MSG = "That mailbox is already in use by another process on %1$s mail server for login %2$s (user=%3$s, context=%4$s). Please try again later. Error message: %5$s";;
 
 }
