@@ -70,6 +70,8 @@ public final class RFC2231Tools {
 
     private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(RFC2231Tools.class));
 
+    private static final Locale ENGLISH = Locale.ENGLISH;
+
     /**
      * No instantiation
      */
@@ -163,7 +165,7 @@ public final class RFC2231Tools {
             return cs.decode(bb).toString();
         } catch (final java.nio.BufferOverflowException e) {
             LOG.warn(
-                new StringBuilder(96).append("Decoding with charset \"").append(charset).append("\" failed for input string: \"").append(
+                new com.openexchange.java.StringAllocator(96).append("Decoding with charset \"").append(charset).append("\" failed for input string: \"").append(
                     encoded).append('"').toString(),
                 e);
             /*
@@ -268,20 +270,20 @@ public final class RFC2231Tools {
         } else if (!Charset.isSupported(charset)) {
             return toEncode;
         }
-        final StringBuilder retval = new StringBuilder(toEncode.length() * 3);
+        final com.openexchange.java.StringAllocator retval = new com.openexchange.java.StringAllocator(toEncode.length() * 3);
         if (prepend) {
-            retval.append(charset.toLowerCase(Locale.ENGLISH)).append('\'').append(
+            retval.append(charset.toLowerCase(ENGLISH)).append('\'').append(
                 (language == null) || (language.length() == 0) ? "" : language).append('\'');
         }
-        final char[] chars = toEncode.toCharArray();
         try {
             final Charset cs = Charsets.forName(charset);
-            for (int i = 0; i < chars.length; i++) {
-                final char c = chars[i];
+            final int length = toEncode.length();
+            for (int i = 0; i < length; i++) {
+                final char c = toEncode.charAt(i);
                 if (!isAscii(c) || (c == ' ')) {
                     final byte[] bytes = String.valueOf(c).getBytes(cs);
                     for (int j = 0; j < bytes.length; j++) {
-                        retval.append('%').append(Integer.toHexString(bytes[j] & 0xFF).toUpperCase(Locale.ENGLISH));
+                        retval.append('%').append(Integer.toHexString(bytes[j] & 0xFF).toUpperCase(ENGLISH));
                     }
                 } else {
                     retval.append(c);
@@ -303,10 +305,16 @@ public final class RFC2231Tools {
      * @return <code>true</code> if string's characters are ASCII 7 bit; otherwise <code>false</code>
      */
     public static boolean isAscii(final String s) {
-        final char[] chars = s.toCharArray();
+        if (null == s) {
+            return true;
+        }
+        final int length = s.length();
+        if (0 == length) {
+            return true;
+        }
         boolean isAscci = true;
-        for (int i = 0; (i < chars.length) && isAscci; i++) {
-            isAscci &= (chars[i] < 128);
+        for (int i = 0; (i < length) && isAscci; i++) {
+            isAscci &= (s.charAt(i) < 128);
         }
         return isAscci;
     }
