@@ -75,6 +75,15 @@ public interface MailAccountStorageService {
      */
     public void invalidateMailAccount(int id, int user, int cid) throws OXException;
 
+    /**
+     * Invalidates user mail accounts.
+     *
+     * @param user The user ID
+     * @param cid The context ID
+     * @throws OXException If invalidation fails
+     */
+    public void invalidateMailAccounts(int user, int cid) throws OXException;
+
     /**
      * Gets the mail account identified by specified ID.
      *
@@ -282,13 +291,12 @@ public interface MailAccountStorageService {
     /**
      * Decodes stored encrypted strings using the old secret and encode them again using the new secret.
      *
-     * @param user The user ID
-     * @param cid The context ID
      * @param oldSecret The secret used for decrypting the stored passwords
      * @param newSecret The secret to use for encrypting the passwords again
-     * @throws OXException
+     * @param session The session
+     * @throws OXException If migrate attempt fails
      */
-    public void migratePasswords(int user, int cid, String oldSecret, String newSecret) throws OXException;
+    public void migratePasswords(String oldSecret, String newSecret, Session session) throws OXException;
 
     /**
      * Finds out whether the user has items that are encrypted
@@ -303,4 +311,13 @@ public interface MailAccountStorageService {
      * @throws OXException If operation fails
      */
     public void cleanUp(String secret, Session session) throws OXException;
+
+    /**
+     * Removes accounts that could no more be decrypted with given secret
+     *
+     * @param secret The current secret
+     * @param session The session providing user information
+     * @throws OXException If operation fails
+     */
+    public void removeUnrecoverableItems(String secret, Session session) throws OXException;
 }
