@@ -94,6 +94,11 @@ final class SanitizingStorageService implements MailAccountStorageService {
         storageService.invalidateMailAccount(id, user, cid);
     }
 
+    @Override
+    public void invalidateMailAccounts(final int user, final int cid) throws OXException {
+        storageService.invalidateMailAccounts(user, cid);
+    }
+
     @Override
     public MailAccount getMailAccount(final int id, final int user, final int cid) throws OXException {
         try {
@@ -217,8 +222,8 @@ final class SanitizingStorageService implements MailAccountStorageService {
     }
 
     @Override
-    public void migratePasswords(final int user, final int cid, final String oldSecret, final String newSecret) throws OXException {
-        storageService.migratePasswords(user, cid, oldSecret, newSecret);
+    public void migratePasswords(final String oldSecret, final String newSecret, final Session session) throws OXException {
+        storageService.migratePasswords(oldSecret, newSecret, session);
     }
 
     @Override
@@ -226,6 +231,11 @@ final class SanitizingStorageService implements MailAccountStorageService {
         storageService.cleanUp(secret, session);
     }
 
+    @Override
+    public void removeUnrecoverableItems(final String secret, final Session session) throws OXException {
+        storageService.removeUnrecoverableItems(secret, session);
+    }
+
     @Override
     public boolean hasAccounts(final Session session) throws OXException {
         return storageService.hasAccounts(session);
