@@ -97,7 +97,7 @@ public final class GetTreeAction extends AbstractMailAccountTreeAction {
                 Integer.valueOf(session.getContextId()));
         }
 
-        if (!session.getUserConfiguration().isMultipleMailAccounts() && !isDefaultMailAccount(mailAccount)) {
+        if (!session.getUserPermissionBits().isMultipleMailAccounts() && !isDefaultMailAccount(mailAccount)) {
             throw
                 MailAccountExceptionCodes.NOT_ENABLED.create(
                 Integer.valueOf(session.getUserId()),
