@@ -53,11 +53,8 @@ import static com.openexchange.mail.MailServletInterface.mailInterfaceMonitor;
 import static com.openexchange.monitoring.MonitorUtility.getObjectName;
 import javax.management.MalformedObjectNameException;
 import javax.management.ObjectName;
-import org.apache.commons.logging.Log;
 import org.osgi.framework.BundleContext;
 import com.openexchange.groupware.update.tools.UpdateTaskMBeanInit;
-import com.openexchange.json.JSONMBean;
-import com.openexchange.json.JSONMBeanImpl;
 import com.openexchange.log.LogFactory;
 import com.openexchange.management.ManagementService;
 import com.openexchange.osgi.BundleServiceTracker;
@@ -72,10 +69,7 @@ import com.openexchange.tools.oxfolder.OXFolderProperties;
  */
 public final class ManagementServiceTracker extends BundleServiceTracker<ManagementService> {
 
-    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ManagementServiceTracker.class));
-
-    private ObjectName gadObjectName;
-    private ObjectName jsonObjectName;
+    private volatile ObjectName gadObjectName;
 
     /**
      * Initializes a new {@link ManagementServiceTracker}
@@ -98,15 +92,12 @@ public final class ManagementServiceTracker extends BundleServiceTracker<Managem
              */
             gadObjectName = OXFolderProperties.registerRestorerMBean(managementService);
             managementService.registerMBean(getObjectName(mailInterfaceMonitor.getClass().getName(), true), mailInterfaceMonitor);
-            final ObjectName jsonObjectName = new ObjectName("org.json", "name", JSONMBean.class.getSimpleName());
-            this.jsonObjectName = jsonObjectName;
-            managementService.registerMBean(jsonObjectName, new JSONMBeanImpl());
         } catch (final MalformedObjectNameException e) {
-            LOG.error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(LogFactory.getLog(ManagementServiceTracker.class)).error(e.getMessage(), e);
         } catch (final NullPointerException e) {
-            LOG.error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(LogFactory.getLog(ManagementServiceTracker.class)).error(e.getMessage(), e);
         } catch (final Exception e) {
-            LOG.error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(LogFactory.getLog(ManagementServiceTracker.class)).error(e.getMessage(), e);
         }
         new ReportingInit(managementService).start();
         new UpdateTaskMBeanInit(managementService).start();
@@ -120,17 +111,19 @@ public final class ManagementServiceTracker extends BundleServiceTracker<Managem
             /*
              * Remove all mbeans since management service now disappears
              */
-            managementService.unregisterMBean(jsonObjectName);
             managementService.unregisterMBean(getObjectName(mailInterfaceMonitor.getClass().getName(), true));
-            OXFolderProperties.unregisterRestorerMBean(gadObjectName, managementService);
+            final ObjectName gadObjectName = this.gadObjectName;
+            if (null != gadObjectName) {
+                OXFolderProperties.unregisterRestorerMBean(gadObjectName, managementService);
+            }
         } catch (final MalformedObjectNameException e) {
-            LOG.error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(LogFactory.getLog(ManagementServiceTracker.class)).error(e.getMessage(), e);
         } catch (final NullPointerException e) {
-            LOG.error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(LogFactory.getLog(ManagementServiceTracker.class)).error(e.getMessage(), e);
         } catch (final Exception e) {
-            LOG.error(e.getMessage(), e);
+            com.openexchange.log.Log.valueOf(LogFactory.getLog(ManagementServiceTracker.class)).error(e.getMessage(), e);
         } finally {
-            gadObjectName = null;
+            this.gadObjectName = null;
         }
     }
 
