@@ -64,6 +64,8 @@ import javax.servlet.http.HttpServletResponse;
 public class DevNullServlet extends HttpServlet {
     @Override
     protected void service(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
+        // create a new HttpSession if it's missing
+        request.getSession(true);
         response.getWriter().write("OK");
     }
 }
