@@ -93,6 +93,10 @@ public enum SubscriptionErrorMessage implements OXExceptionCode {
     INACTIVE_SOURCE(CATEGORY_CONFIGURATION, 10, SubscriptionErrorStrings.INACTIVE_SOURCE, SubscriptionErrorStrings.SUBSCRIPTION_SOURCE_CANT_PROVIDE_DATA),
     MISSING_ARGUMENT(CATEGORY_USER_INPUT, 11, SubscriptionErrorStrings.MISSING_ARGUMENT, SubscriptionErrorStrings.MISSING_ARGUMENT),
     PERMISSION_DENIED(CATEGORY_WARNING, 12, SubscriptionErrorStrings.PERMISSION_DENIED, SubscriptionErrorStrings.PERMISSION_DENIED),
+    /**
+     * Please specify your full E-Mail address as login name.
+     */
+    EMAIL_ADDR_LOGIN(CATEGORY_TRY_AGAIN, 13, SubscriptionErrorStrings.EMAIL_ADDR_LOGIN, SubscriptionErrorStrings.EMAIL_ADDR_LOGIN),
     /**
      * An unexpected error occurred: %1$s.
      */
