@@ -98,7 +98,7 @@ public class UpdateAction extends TaskAction {
 
         final Task task = new Task();
 
-        final JSONObject jsonobject = (JSONObject) req.getRequest().getData();
+        final JSONObject jsonobject = (JSONObject) req.getRequest().requireData();
         ServerSession session = req.getSession();
         final TaskParser taskParser = new TaskParser(req.getTimeZone());
         taskParser.parse(task, jsonobject, session.getUser().getLocale());
