@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2012, Hazel Bilisim Ltd. All Rights Reserved.
+ * Copyright (c) 2008-2012, Hazelcast, Inc. All Rights Reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -481,9 +481,9 @@ public final class ClusterManager extends BaseManager implements ConnectionListe
                 }
             }
             node.setMasterAddress(master.address);
-            final Connection connMaster = node.connectionManager.getOrConnect(master.address);
-            if (connMaster != null) {
-                sendJoinRequest(master.address, true);
+            node.connectionManager.getOrConnect(master.address);
+            if (!sendJoinRequest(master.address, true)) {
+                logger.log(Level.WARNING, "Could not create connection to possible master " + master.address);
             }
         }
     }
@@ -539,7 +539,7 @@ public final class ClusterManager extends BaseManager implements ConnectionListe
             removeMember(deadMember);
             node.getClusterImpl().setMembers(lsMembers);
             node.concurrentMapManager.syncForDead(deadMember);
-            node.blockingQueueManager.syncForDead(deadMember);
+            node.blockingQueueManager.syncForDead(deadAddress);
             node.listenerManager.syncForDead(deadAddress);
             node.topicManager.syncForDead(deadAddress);
             // node.getClusterImpl().setMembers(lsMembers); // shifted up to get members in syncForDead methods
@@ -909,7 +909,12 @@ public final class ClusterManager extends BaseManager implements ConnectionListe
         if (toAddress == null) {
             toAddress = node.getMasterAddress();
         }
-        return sendProcessableTo(node.createJoinInfo(withCredentials), toAddress);
+        logger.log(Level.INFO, "Sending join request to " + toAddress);
+        final boolean send = sendProcessableTo(node.createJoinInfo(withCredentials), toAddress);
+        if (!send) {
+            logger.log(Level.WARNING, "Could not send join request to " + toAddress);
+        }
+        return send;
     }
 
     public void registerScheduledAction(ScheduledAction scheduledAction) {
