@@ -70,7 +70,7 @@ public class MapConfig implements DataSerializable {
 
     private MapStoreConfig mapStoreConfig = null;
 
-    private NearCacheConfig nearCacheConfig = null;
+    private NearCacheConfig nearCacheConfig =new NearCacheConfig();
 
     private boolean readBackupData = false;
 
@@ -607,8 +607,9 @@ public class MapConfig implements DataSerializable {
         evictionPolicy = in.readUTF();
         mergePolicy = in.readUTF();
 //        clearQuick = in.readBoolean();
-        // TODO: MapStoreConfig mapStoreConfig
-        // TODO: NearCacheConfig nearCacheConfig
+        nearCacheConfig = new NearCacheConfig();
+        nearCacheConfig.readData(in);
+//        TODO: MapStoreConfig mapStoreConfig
     }
 
     public void writeData(DataOutput out) throws IOException {
@@ -624,8 +625,8 @@ public class MapConfig implements DataSerializable {
         out.writeUTF(evictionPolicy);
         out.writeUTF(mergePolicy);
 //        out.writeBoolean(clearQuick);
-        // TODO: MapStoreConfig mapStoreConfig
-        // TODO: NearCacheConfig nearCacheConfig
+        nearCacheConfig.writeData(out);
+//        TODO: MapStoreConfig mapStoreConfig
     }
 
     @Override
