@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2012, Hazelcast, Inc. All Rights Reserved.
+ * Copyright (c) 2008-2012, Hazel Bilisim Ltd. All Rights Reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -281,7 +281,7 @@ public abstract class AbstractRecord extends AbstractSimpleRecord implements Rec
         if (expirationTime == Long.MAX_VALUE && maxIdleMillis == Long.MAX_VALUE) {
             return true;
         }
-        long lastTouch = Math.max(lastUpdateTime, Math.max(lastAccessTime, creationTime));
+        long lastTouch = Math.max(lastAccessTime, creationTime);
         long idle = now - lastTouch;
         return expirationTime > now && (maxIdleMillis > idle);
     }
