@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2012, Hazelcast, Inc. All Rights Reserved.
+ * Copyright (c) 2008-2012, Hazel Bilisim Ltd. All Rights Reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -44,7 +44,6 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.concurrent.atomic.AtomicBoolean;
-import java.util.concurrent.atomic.AtomicLong;
 import java.util.logging.Level;
 
 import static com.hazelcast.core.Prefix.*;
@@ -106,8 +105,6 @@ public class CMap {
 
     private boolean cacheValue;
 
-    private boolean clearQuick = false;
-
     private volatile boolean ttlPerRecord = false;
 
     private volatile boolean dirty = false;
@@ -125,8 +122,6 @@ public class CMap {
 
     private volatile long totalCostOfRecords = 0L;
 
-    private AtomicLong totalGetCount = new AtomicLong(0);
-
     private MapStoreWrapper mapStoreWrapper;
 
     final MapLoader loader;
@@ -342,7 +337,6 @@ public class CMap {
                 : EvictionPolicy.NONE;
         readBackupData = mapConfig.isReadBackupData();
         cacheValue = mapConfig.isCacheValue();
-        clearQuick = mapConfig.isClearQuick();
         MaxSizeConfig maxSizeConfig = mapConfig.getMaxSizeConfig();
         if (MaxSizeConfig.POLICY_MAP_SIZE_PER_JVM.equals(maxSizeConfig.getMaxSizePolicy())) {
             maxSizePolicy = new MaxSizePerJVMPolicy(maxSizeConfig);
@@ -454,10 +448,6 @@ public class CMap {
         return cacheValue;
     }
 
-    public boolean isClearQuick() {
-        return clearQuick;
-    }
-
     public boolean isReadBackupData() {
         return readBackupData;
     }
@@ -1184,7 +1174,6 @@ public class CMap {
         localMapStats.setLockWaitCount(zeroOrPositive(lockWaitCount));
         localMapStats.setLockedEntryCount(zeroOrPositive(lockedEntryCount));
         localMapStats.setHits(zeroOrPositive(hits));
-        localMapStats.setMisses(totalGetCount.get() - localMapStats.getHits());
         localMapStats.setOwnedEntryCount(zeroOrPositive(ownedEntryCount));
         localMapStats.setBackupEntryCount(zeroOrPositive(backupEntryCount));
         localMapStats.setOwnedEntryMemoryCost(zeroOrPositive(ownedEntryMemoryCost));
@@ -1194,10 +1183,6 @@ public class CMap {
         return localMapStats;
     }
 
-    public void incrementGetCount() {
-        totalGetCount.incrementAndGet();
-    }
-
     private static long zeroOrPositive(long value) {
         return (value > 0) ? value : 0;
     }
@@ -1658,14 +1643,6 @@ public class CMap {
         mapIndexService.clear();
     }
 
-    void clearQuick() {
-        if (nearCache != null) {
-            nearCache.reset();
-        }
-        mapRecords.clear();
-        mapIndexService.clear();
-    }
-
     void destroy() {
         reset(true);
         node.listenerManager.removeAllRegisteredListeners(getName());
