@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2012, Hazel Bilisim Ltd. All Rights Reserved.
+ * Copyright (c) 2008-2012, Hazelcast, Inc. All Rights Reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -285,7 +285,8 @@ public class ListenerManager extends BaseManager {
         List<ListenerItem> listeners = namedListeners.get(name);
         if (listeners == null) return;
         for (ListenerItem listenerItem : listeners) {
-            if (listener == listenerItem.listener && listenerItem.name.equals(name)) {
+            if (listener != null && listener.equals(listenerItem.listener)
+                    && listenerItem.name.equals(name)) {
                 if (key == null && listenerItem.key == null) {
                     listeners.remove(listenerItem);
                 } else if (key != null && key.equals(listenerItem.key)) {
@@ -406,10 +407,10 @@ public class ListenerManager extends BaseManager {
                 ItemListener itemListener = (ItemListener) listener;
                 switch (entryEventType) {
                     case ADDED:
-                        itemListener.itemAdded(new DataAwareItemEvent(listenerItem.name, ItemEventType.ADDED, event.getKeyData()));
+                        itemListener.itemAdded(new DataAwareItemEvent(listenerItem.name, ItemEventType.ADDED, event.getKeyData(), event.getMember()));
                         break;
                     case REMOVED:
-                        itemListener.itemRemoved(new DataAwareItemEvent(listenerItem.name, ItemEventType.REMOVED, event.getKeyData()));
+                        itemListener.itemRemoved(new DataAwareItemEvent(listenerItem.name, ItemEventType.REMOVED, event.getKeyData(), event.getMember()));
                         break;
                 }
                 break;
@@ -421,10 +422,10 @@ public class ListenerManager extends BaseManager {
                 ItemListener queueItemListener = (ItemListener) listener;
                 switch (entryEventType) {
                     case ADDED:
-                        queueItemListener.itemAdded(new DataAwareItemEvent(listenerItem.name, ItemEventType.ADDED, event.getNewValueData()));
+                        queueItemListener.itemAdded(new DataAwareItemEvent(listenerItem.name, ItemEventType.ADDED, event.getNewValueData(), event.getMember()));
                         break;
                     case REMOVED:
-                        queueItemListener.itemRemoved(new DataAwareItemEvent(listenerItem.name, ItemEventType.REMOVED, event.getNewValueData()));
+                        queueItemListener.itemRemoved(new DataAwareItemEvent(listenerItem.name, ItemEventType.REMOVED, event.getNewValueData(), event.getMember()));
                         break;
                 }
                 break;
