@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2012, Hazelcast, Inc. All Rights Reserved.
+ * Copyright (c) 2008-2013, Hazelcast, Inc. All Rights Reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -36,7 +36,7 @@ public class ShutdownMemberRequest implements ConsoleRequest {
     }
 
     public void writeResponse(ManagementCenterService mcs, DataOutput dos) throws Exception {
-        mcs.getHazelcastInstance().shutdown();
+        mcs.getHazelcastInstance().getLifecycleService().shutdown();
         dos.writeUTF("successful");
     }
 
