@@ -230,7 +230,7 @@ public class LocalMapStatsImpl extends LocalInstanceStatsSupport<LocalMapOperati
                 ", lastUpdateTime=" + lastUpdateTime +
                 ", lastEvictionTime=" + lastEvictionTime +
                 ", hits=" + hits.get() +
-//                ", misses=" + misses.get() +
+                ", misses=" + misses.get() +
                 ", lockedEntryCount=" + lockedEntryCount +
                 ", lockWaitCount=" + lockWaitCount +
                 ", dirtyEntryCount=" + dirtyEntryCount +
