@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2012, Hazel Bilisim Ltd. All Rights Reserved.
+ * Copyright (c) 2008-2012, Hazelcast, Inc. All Rights Reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -50,10 +50,6 @@ public class PartitionInfo {
         return addresses.get(0);
     }
 
-    public void setOwner(Address ownerAddress) {
-        setReplicaAddress(0, ownerAddress);
-    }
-
     public void setReplicaAddress(int index, Address address) {
         boolean changed = false;
         Address currentAddress = addresses.get(index);
