@@ -56,6 +56,7 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Properties;
+import java.util.Vector;
 import javax.mail.Flags;
 import javax.mail.Folder;
 import javax.mail.Quota;
@@ -98,7 +99,6 @@ import com.sun.mail.util.PropUtil;
 
 public class IMAPProtocol extends Protocol {
     
-    private boolean failOnNOFetch = false; // Whether a NO response for issued FETCH throws a CommandFailedException or only returns null
     private boolean connected = false;	// did constructor succeed?
     private boolean rev1 = false;	// REV1 server ?
     private boolean noauthdebug = true;	// hide auth info in debug output
@@ -278,16 +278,6 @@ public class IMAPProtocol extends Protocol {
     }
     }
 
-    
-    /**
-     * Sets whether a NO response for issued FETCH throws a <tt>CommandFailedException</tt> or only returns <tt>null</tt>
-     * 
-     * @param failOnNOFetch <code>true</code> to throws a <tt>CommandFailedException</tt>; otherwise return <tt>null</tt> 
-     */
-    public void setFailOnNOFetch(final boolean failOnNOFetch) {
-    this.failOnNOFetch = failOnNOFetch;
-    }
-
     /**
      * Returns <code>true</code> if the connection has been authenticated,
      * either due to a successful login, or due to a PREAUTH greeting response.
@@ -457,7 +447,7 @@ public class IMAPProtocol extends Protocol {
      */
     public synchronized void authlogin(final String u, final String p)
 				throws ProtocolException {
-	final List<Response> v = new ArrayList<Response>();
+	final Vector v = new Vector();
 	String tag = null;
 	Response r = null;
 	boolean done = false;
@@ -527,7 +517,7 @@ public class IMAPProtocol extends Protocol {
         } else if (r.isBYE()) {
             done = true;
         } else {
-            v.add(r);
+            v.addElement(r);
         }
 	    } catch (final Exception ioex) {
 		// convert this into a BYE response
@@ -546,7 +536,8 @@ public class IMAPProtocol extends Protocol {
 	 * connection has been authenticated. So, for now, the below
 	 * code really ends up being just a no-op.
 	 */
-	final Response[] responses = v.toArray(new Response[v.size()]);
+	final Response[] responses = new Response[v.size()];
+	v.copyInto(responses);
 	notifyResponseHandlers(responses);
 
 	// Handle the final OK, NO, BAD or BYE response
@@ -575,7 +566,7 @@ public class IMAPProtocol extends Protocol {
      */
     public synchronized void authplain(final String authzid, final String u, final String p)
 				throws ProtocolException {
-    final List<Response> v = new ArrayList<Response>();
+	final Vector v = new Vector();
 	String tag = null;
 	Response r = null;
 	boolean done = false;
@@ -640,7 +631,7 @@ public class IMAPProtocol extends Protocol {
         } else if (r.isBYE()) {
             done = true;
         } else {
-            v.add(r);
+            v.addElement(r);
         }
 	    } catch (final Exception ioex) {
 		// convert this into a BYE response
@@ -659,7 +650,8 @@ public class IMAPProtocol extends Protocol {
 	 * connection has been authenticated. So, for now, the below
 	 * code really ends up being just a no-op.
 	 */
-	final Response[] responses = v.toArray(new Response[v.size()]);
+	final Response[] responses = new Response[v.size()];
+	v.copyInto(responses);
 	notifyResponseHandlers(responses);
 
 	// Handle the final OK, NO, BAD or BYE response
@@ -687,7 +679,7 @@ public class IMAPProtocol extends Protocol {
      */
     public synchronized void authntlm(final String authzid, final String u, final String p)
 				throws ProtocolException {
-    final List<Response> v = new ArrayList<Response>();
+	final Vector v = new Vector();
 	String tag = null;
 	Response r = null;
 	boolean done = false;
@@ -740,7 +732,7 @@ public class IMAPProtocol extends Protocol {
         } else if (r.isBYE()) {
             done = true;
         } else {
-            v.add(r);
+            v.addElement(r);
         }
 	    } catch (final Exception ioex) {
 		// convert this into a BYE response
@@ -760,7 +752,8 @@ public class IMAPProtocol extends Protocol {
 	 * connection has been authenticated. So, for now, the below
 	 * code really ends up being just a no-op.
 	 */
-	final Response[] responses = v.toArray(new Response[v.size()]);
+	final Response[] responses = new Response[v.size()];
+	v.copyInto(responses);
 	notifyResponseHandlers(responses);
 
 	// Handle the final OK, NO, BAD or BYE response
@@ -1161,7 +1154,7 @@ public class IMAPProtocol extends Protocol {
 	final Response response = r[r.length-1];
 
 	if (response.isOK()) { // command succesful 
-	    final List<ListInfo> v = new ArrayList<ListInfo>(1);
+	    final Vector v = new Vector(1);
 	    for (int i = 0, len = r.length; i < len; i++) {
 		if (!(r[i] instanceof IMAPResponse)) {
             continue;
@@ -1169,12 +1162,13 @@ public class IMAPProtocol extends Protocol {
 
 		final IMAPResponse ir = (IMAPResponse)r[i];
 		if (ir.keyEquals(cmd)) {
-		    v.add(new ListInfo(ir));
+		    v.addElement(new ListInfo(ir));
 		    r[i] = null;
 		}
 	    }
 	    if (v.size() > 0) {
-		linfo = v.toArray(new ListInfo[v.size()]);
+		linfo = new ListInfo[v.size()];
+		v.copyInto(linfo);
 	    }
 	}
 	
@@ -1337,25 +1331,6 @@ public class IMAPProtocol extends Protocol {
 	}
     }
 
-    /**
-     * Fetch the BODYSTRUCTURE of the specified message.
-     */
-    public BODYSTRUCTURE fetchBodyStructure(final long uid) 
-            throws ProtocolException {
-    final Response[] r = fetch(uid, "BODYSTRUCTURE");
-    notifyResponseHandlers(r);
-
-    final Response response = r[r.length-1];
-    if (response.isOK()) {
-        return (BODYSTRUCTURE)FetchResponse.getItem(r, BODYSTRUCTURE.class);
-    } else if (response.isNO()) {
-        return null;
-    } else {
-        handleResult(response);
-        return null;
-    }
-    }
-
     /**
      * Fetch given BODY section, without marking the message
      * as SEEN.
@@ -1365,15 +1340,6 @@ public class IMAPProtocol extends Protocol {
 	return fetchBody(msgno, section, true);
     }
 
-    /**
-     * Fetch given BODY section, without marking the message
-     * as SEEN.
-     */
-    public BODY peekBody(final long uid, final String section)
-            throws ProtocolException {
-    return fetchBody(uid, section, true);
-    }
-
     /**
      * Fetch given BODY section.
      */
@@ -1382,14 +1348,6 @@ public class IMAPProtocol extends Protocol {
 	return fetchBody(msgno, section, false);
     }
 
-    /**
-     * Fetch given BODY section.
-     */
-    public BODY fetchBody(final long uid, final String section)
-            throws ProtocolException {
-    return fetchBody(uid, section, false);
-    }
-
     protected BODY fetchBody(final int msgno, final String section, final boolean peek)
 			throws ProtocolException {
 	Response[] r;
@@ -1408,9 +1366,6 @@ public class IMAPProtocol extends Protocol {
 	if (response.isOK()) {
         return (BODY)FetchResponse.getItem(r, msgno, BODY.class);
     } else if (response.isNO()) {
-        if (failOnNOFetch) {
-            throw new CommandFailedException(response);
-        }
         return null;
     } else {
 	    handleResult(response);
@@ -1418,34 +1373,6 @@ public class IMAPProtocol extends Protocol {
 	}
     }
 
-    protected BODY fetchBody(final long uid, final String section, final boolean peek)
-        throws ProtocolException {
-    Response[] r;
-    
-    if (peek) {
-        r = fetch(uid,
-             "BODY.PEEK[" + (section == null ? "]" : section + "]"));
-    } else {
-        r = fetch(uid,
-             "BODY[" + (section == null ? "]" : section + "]"));
-    }
-    
-    notifyResponseHandlers(r);
-    
-    final Response response = r[r.length-1];
-    if (response.isOK()) {
-        return (BODY)FetchResponse.getItem(r, BODY.class);
-    } else if (response.isNO()) {
-        if (failOnNOFetch) {
-            throw new CommandFailedException(response);
-        }
-        return null;
-    } else {
-        handleResult(response);
-        return null;
-    }
-    }
-
     /**
      * Partial FETCH of given BODY section, without setting SEEN flag.
      */
@@ -1478,66 +1405,27 @@ public class IMAPProtocol extends Protocol {
 	return fetchBody(msgno, section, start, size, false, ba);
     }
 
-    /**
-     * Partial UID FETCH of given BODY section, without setting SEEN flag.
-     */
-    public BODY peekBody(final long msgno, final String section, final int start, final int size,
-                final ByteArray ba) throws ProtocolException {
-    return fetchBody(msgno, section, start, size, true, ba);
-    }
-
-    /**
-     * Partial UID FETCH of given BODY section.
-     */
-    public BODY fetchBody(final long msgno, final String section, final int start, final int size,
-                final ByteArray ba) throws ProtocolException {
-    return fetchBody(msgno, section, start, size, false, ba);
-    }
-
     protected BODY fetchBody(final int msgno, final String section, final int start, final int size,
 			final boolean peek, final ByteArray ba) throws ProtocolException {
-    	this.ba = ba;	// save for later use by getResponseBuffer
-    	StringBuilder sb = new StringBuilder(32);
-        sb.append((peek ? "BODY.PEEK[" : "BODY[" ));
-        sb.append((section == null ? "]<" : (section +"]<")));
-        sb.append(start).append('.').append(size).append('>');
-    	final Response[] r = fetch(msgno, sb.toString());
-    	sb = null;
-    
-    	notifyResponseHandlers(r);
-    
-    	final Response response = r[r.length-1];
-    	if (response.isOK()) {
-            return (BODY)FetchResponse.getItem(r, msgno, BODY.class);
-        } else if (response.isNO()) {
-            return null;
-        } else {
-    	    handleResult(response);
-    	    return null;
-    	}
-    }
+	this.ba = ba;	// save for later use by getResponseBuffer
+	final Response[] r = fetch(
+			msgno, (peek ? "BODY.PEEK[" : "BODY[" ) +
+			(section == null ? "]<" : (section +"]<")) +
+			String.valueOf(start) + "." +
+			String.valueOf(size) + ">"
+		       );
 
-    protected BODY fetchBody(final long msgno, final String section, final int start, final int size,
-        final boolean peek, final ByteArray ba) throws ProtocolException {
-        this.ba = ba;   // save for later use by getResponseBuffer
-        StringBuilder sb = new StringBuilder(32);
-        sb.append((peek ? "BODY.PEEK[" : "BODY[" ));
-        sb.append((section == null ? "]<" : (section +"]<")));
-        sb.append(start).append('.').append(size).append('>');
-        final Response[] r = fetch(msgno, sb.toString());
-        sb = null;
-        
-        notifyResponseHandlers(r);
-        
-        final Response response = r[r.length-1];
-        if (response.isOK()) {
-            return (BODY)FetchResponse.getItem(r, BODY.class);
-        } else if (response.isNO()) {
-            return null;
-        } else {
-            handleResult(response);
-            return null;
-        }
+	notifyResponseHandlers(r);
+
+	final Response response = r[r.length-1];
+	if (response.isOK()) {
+        return (BODY)FetchResponse.getItem(r, msgno, BODY.class);
+    } else if (response.isNO()) {
+        return null;
+    } else {
+	    handleResult(response);
+	    return null;
+	}
     }
 
     /**
@@ -1606,32 +1494,6 @@ public class IMAPProtocol extends Protocol {
 	return flags;
     }
 
-    /**
-     * Fetch the FLAGS for the given message.
-     */
-    public Flags fetchFlags(final long uid) throws ProtocolException {
-    Flags flags = null;
-    final Response[] r = fetch(uid, "FLAGS");
-
-    // Search for our FLAGS response
-    for (int i = 0, len = r.length; i < len; i++) {
-        if (r[i] == null || !(r[i] instanceof FetchResponse)) {
-            continue;
-        }       
-        
-        final FetchResponse fr = (FetchResponse)r[i];
-        if ((flags = (Flags)fr.getItem(Flags.class)) != null) {
-        r[i] = null; // remove this response
-        break;
-        }
-    }
-
-    // dispatch untagged responses
-    notifyResponseHandlers(r);
-    handleResult(r[r.length-1]);
-    return flags;
-    }
-
     /**
      * Fetch the IMAP UID for the given message.
      */
@@ -1694,7 +1556,7 @@ public class IMAPProtocol extends Protocol {
 			     "UID", true);	
 
 	UID u;
-	final List<UID> v = new ArrayList<UID>(r.length);
+	final Vector v = new Vector();
 	for (int i = 0, len = r.length; i < len; i++) {
 	    if (r[i] == null || !(r[i] instanceof FetchResponse)) {
             continue;
@@ -1702,14 +1564,16 @@ public class IMAPProtocol extends Protocol {
 	    
 	    final FetchResponse fr = (FetchResponse)r[i];
 	    if ((u = (UID)fr.getItem(UID.class)) != null) {
-            v.add(u);
+            v.addElement(u);
         }
 	}
 		
 	notifyResponseHandlers(r);
 	handleResult(r[r.length-1]);
 
-	return v.toArray(new UID[v.size()]);
+	final UID[] ua = new UID[v.size()];
+	v.copyInto(ua);
+	return ua;
     }
 
     /**
@@ -1718,7 +1582,7 @@ public class IMAPProtocol extends Protocol {
      * If no UIDs in the given range are found, an empty array is returned.
      */
     public UID[] fetchSequenceNumbers(final long[] uids) throws ProtocolException {
-	final StringBuilder sb = new StringBuilder();
+	final StringBuffer sb = new StringBuffer();
 	for (int i = 0; i < uids.length; i++) {
 	    if (i > 0) {
             sb.append(",");
@@ -1729,7 +1593,7 @@ public class IMAPProtocol extends Protocol {
 	final Response[] r = fetch(sb.toString(), "UID", true);	
 
 	UID u;
-	final List<UID> v = new ArrayList<UID>();
+	final Vector v = new Vector();
 	for (int i = 0, len = r.length; i < len; i++) {
 	    if (r[i] == null || !(r[i] instanceof FetchResponse)) {
             continue;
@@ -1737,14 +1601,16 @@ public class IMAPProtocol extends Protocol {
 	    
 	    final FetchResponse fr = (FetchResponse)r[i];
 	    if ((u = (UID)fr.getItem(UID.class)) != null) {
-            v.add(u);
+            v.addElement(u);
         }
 	}
 		
 	notifyResponseHandlers(r);
 	handleResult(r[r.length-1]);
 
-	return v.toArray(new UID[v.size()]);
+	final UID[] ua = new UID[v.size()];
+	v.copyInto(ua);
+	return ua;
     }
 
     public Response[] fetch(final MessageSet[] msgsets, final String what)
@@ -1763,17 +1629,12 @@ public class IMAPProtocol extends Protocol {
 	return fetch(String.valueOf(msg), what, false);
     }
 
-    public Response[] fetch(final long msg, final String what) 
-        throws ProtocolException {
-    return fetch(Long.toString(msg), what, true);
-    }
-
     private Response[] fetch(final String msgSequence, final String what, final boolean uid)
 			throws ProtocolException {
 	if (uid) {
-        return command("UID FETCH " + msgSequence +" (" + what + ')',null);
+        return command("UID FETCH " + msgSequence +" (" + what + ")",null);
     } else {
-        return command("FETCH " + msgSequence + " (" + what + ')', null);
+        return command("FETCH " + msgSequence + " (" + what + ")", null);
     }
     }
 
@@ -1842,7 +1703,7 @@ public class IMAPProtocol extends Protocol {
      * Creates an IMAP flag_list from the given Flags object.
      */
     private String createFlagList(final Flags flags) {
-	final StringBuilder sb = new StringBuilder();
+	final StringBuffer sb = new StringBuffer();
 	sb.append("("); // start of flag_list
 
 	final Flags.Flag[] sf = flags.getSystemFlags(); // get the system flags
@@ -1997,7 +1858,7 @@ public class IMAPProtocol extends Protocol {
 
 	// Grab all SEARCH responses
 	if (response.isOK()) { // command succesful
-	    final List<Integer> v = new ArrayList<Integer>();
+	    final Vector v = new Vector();
 	    int num;
 	    for (int i = 0, len = r.length; i < len; i++) {
 		if (!(r[i] instanceof IMAPResponse)) {
@@ -2008,17 +1869,17 @@ public class IMAPProtocol extends Protocol {
 		// There *will* be one SEARCH response.
 		if (ir.keyEquals("SEARCH")) {
 		    while ((num = ir.readNumber()) != -1) {
-                v.add(Integer.valueOf(num));
+                v.addElement(new Integer(num));
             }
 		    r[i] = null;
 		}
 	    }
 
-	    // Copy the list into 'matches'
+	    // Copy the vector into 'matches'
 	    final int vsize = v.size();
 	    matches = new int[vsize];
 	    for (int i = 0; i < vsize; i++) {
-            matches[i] = v.get(i).intValue();
+            matches[i] = ((Integer)v.elementAt(i)).intValue();
         }
 	}
 
@@ -2077,7 +1938,7 @@ public class IMAPProtocol extends Protocol {
 
 	// Grab all SORT responses
 	if (response.isOK()) { // command succesful
-	    final List<Integer> v = new ArrayList<Integer>(r.length);
+	    final Vector v = new Vector();
 	    int num;
 	    for (int i = 0, len = r.length; i < len; i++) {
 		if (!(r[i] instanceof IMAPResponse)) {
@@ -2087,7 +1948,7 @@ public class IMAPProtocol extends Protocol {
 		final IMAPResponse ir = (IMAPResponse)r[i];
 		if (ir.keyEquals("SORT")) {
 		    while ((num = ir.readNumber()) != -1) {
-                v.add(Integer.valueOf(num));
+                v.addElement(new Integer(num));
             }
 		    r[i] = null;
 		}
@@ -2097,7 +1958,7 @@ public class IMAPProtocol extends Protocol {
 	    final int vsize = v.size();
 	    matches = new int[vsize];
 	    for (int i = 0; i < vsize; i++) {
-            matches[i] = v.get(i).intValue();
+            matches[i] = ((Integer)v.elementAt(i)).intValue();
         }
 	}
 
@@ -2234,7 +2095,7 @@ public class IMAPProtocol extends Protocol {
 	final Response[] r = command("GETQUOTA", args);
 
 	Quota quota = null;
-	final List<Quota> v = new ArrayList<Quota>(r.length);
+	final Vector v = new Vector();
 	final Response response = r[r.length-1];
 
 	// Grab all QUOTA responses
@@ -2247,7 +2108,7 @@ public class IMAPProtocol extends Protocol {
 		final IMAPResponse ir = (IMAPResponse)r[i];
 		if (ir.keyEquals("QUOTA")) {
 		    quota = parseQuota(ir);
-		    v.add(quota);
+		    v.addElement(quota);
 		    r[i] = null;
 		}
 	    }
@@ -2256,7 +2117,9 @@ public class IMAPProtocol extends Protocol {
 	// dispatch remaining untagged responses
 	notifyResponseHandlers(r);
 	handleResult(response);
-	return v.toArray(new Quota[v.size()]);
+	final Quota[] qa = new Quota[v.size()];
+	v.copyInto(qa);
+	return qa;
     }
 
     /**
@@ -2332,7 +2195,7 @@ public class IMAPProtocol extends Protocol {
         throw new ParsingException("parse error in QUOTA");
     }
 
-	final List<Quota.Resource> v = new ArrayList<Quota.Resource>();
+	final Vector v = new Vector();
 	while (r.peekByte() != ')') {
 	    // quota_resource ::= atom SP number SP number
 	    final String name = r.readAtom();
@@ -2340,11 +2203,12 @@ public class IMAPProtocol extends Protocol {
 		final long usage = r.readLong();
 		final long limit = r.readLong();
 		final Quota.Resource res = new Quota.Resource(name, usage, limit);
-		v.add(res);
+		v.addElement(res);
 	    }
 	}
 	r.readByte();
-	q.resources = v.toArray(new Quota.Resource[v.size()]);
+	q.resources = new Quota.Resource[v.size()];
+	v.copyInto(q.resources);
 	return q;
     }
 
@@ -2425,7 +2289,7 @@ public class IMAPProtocol extends Protocol {
 	final Response response = r[r.length-1];
 
 	// Grab all ACL responses
-	final List<ACL> v = new ArrayList<ACL>(r.length);
+	final Vector v = new Vector();
 	if (response.isOK()) { // command succesful 
 	    for (int i = 0, len = r.length; i < len; i++) {
 		if (!(r[i] instanceof IMAPResponse)) {
@@ -2445,7 +2309,7 @@ public class IMAPProtocol extends Protocol {
                 break;
             }
 			final ACL acl = new ACL(name, new Rights(rights));
-			v.add(acl);
+			v.addElement(acl);
 		    }
 		    r[i] = null;
 		}
@@ -2455,7 +2319,9 @@ public class IMAPProtocol extends Protocol {
 	// dispatch remaining untagged responses
 	notifyResponseHandlers(r);
 	handleResult(response);
-	return v.toArray(new ACL[v.size()]);
+	final ACL[] aa = new ACL[v.size()];
+	v.copyInto(aa);
+	return aa;
     }
 
     /**
@@ -2480,7 +2346,7 @@ public class IMAPProtocol extends Protocol {
 	final Response response = r[r.length-1];
 
 	// Grab LISTRIGHTS response
-	final List<Rights> v = new ArrayList<Rights>(r.length);
+	final Vector v = new Vector();
 	if (response.isOK()) { // command succesful 
 	    for (int i = 0, len = r.length; i < len; i++) {
 		if (!(r[i] instanceof IMAPResponse)) {
@@ -2497,7 +2363,7 @@ public class IMAPProtocol extends Protocol {
 		    ir.readAtomString();
 		    String rights;
 		    while ((rights = ir.readAtomString()) != null) {
-                v.add(new Rights(rights));
+                v.addElement(new Rights(rights));
             }
 		    r[i] = null;
 		}
@@ -2507,7 +2373,9 @@ public class IMAPProtocol extends Protocol {
 	// dispatch remaining untagged responses
 	notifyResponseHandlers(r);
 	handleResult(response);
-	return v.toArray(new Rights[v.size()]);
+	final Rights[] ra = new Rights[v.size()];
+	v.copyInto(ra);
+	return ra;
     }
 
     /**
@@ -2585,7 +2453,7 @@ public class IMAPProtocol extends Protocol {
         throw new BadCommandException("IDLE not supported");
     }
 
-	final List<Response> v = new ArrayList<Response>();
+	final Vector v = new Vector();
 	boolean done = false;
 	Response r = null;
 
@@ -2593,11 +2461,11 @@ public class IMAPProtocol extends Protocol {
 	try {
 	    idleTag = writeCommand("IDLE", null);
 	} catch (final LiteralException lex) {
-	    v.add(lex.getResponse());
+	    v.addElement(lex.getResponse());
 	    done = true;
 	} catch (final Exception ex) {
 	    // Convert this into a BYE response
-	    v.add(Response.byeResponse(ex));
+	    v.addElement(Response.byeResponse(ex));
 	    done = true;
 	}
 
@@ -2611,14 +2479,15 @@ public class IMAPProtocol extends Protocol {
 		continue; // skip this response
 	    }
 
-	    v.add(r);
+	    v.addElement(r);
 
 	    if (r.isContinuation() || r.isBYE()) {
             done = true;
         }
 	}
 
-	final Response[] responses = v.toArray(new Response[v.size()]);
+	final Response[] responses = new Response[v.size()];
+	v.copyInto(responses);
 	r = responses[responses.length-1];
 
 	// dispatch remaining untagged responses
